function [d,m]=mkdatebyno(n,yr);
% mkdatebyno        calculation of day and month from the days number
%
% formula from:
%
% Jean Meeus
% "Astronomische Berechnungen"
% 2., durchges. Auflage
% Joh. Ambrosius Barth, Leipzig, Berlin, Heidleberg, 1994
%
% call: [d,m]=mkdatebyno(n,yr)
%
%          n: the number of the day, an integer number from 1 to 365 (366)
%         yr: the year, used to determine the total number of days
%
% result: d: the day, e.g. the 24 in the date of Xmas
%         m: the month, e.g. the 12 in the date of Xmas
%
% THIS FUNCTION MUST HAVE TWO OUTPUT ARGUMENTS
%
% see also mkdayno
%
% M. Knapmeyer, 29.05.1995


k=mkleapyear(yr);

% the month

if n<32
   m=1;
else
   m=fix(9*(k+n)/275+0.98);
end;

% the day

d=n-fix(275*m/9)+k*fix((m+9)/12)+30;

if nargout~=2
   disp(['DOY ' int2str(n) ' ' int2str(yr)...
         ' = ' int2str(d) '.' int2str(m) '.' int2str(yr)]);
end; % if nargout
