function jd=mkjd(y,m,d);
% mkjd..................calculates the julian day from year, month, day
%
% call: jd=mkjd(y,m,d);
%
%       y: the year
%       m: the month
%       d: the day (with decimal fractions, where .0 is 00:00h)
%
% result: jd: the julian day, as astronomers know it
%             .0 is 12:00h (UT)
%         THE RESULT IS VALID FOR NON-NEGATIVE JD ONLY !!!!
%
% Algorithm: from
%
% Jean Meeus
% "Astronomische Berechnungen"
% 2., durchges. Auflage
% Joh. Ambrosius Barth, Leipzig, Berlin, Heidleberg, 1994
%
% The algorithm takes into account that the day after the
% 04.Oct.1582 was the 15.Oct1582 due to the invention of
% the gregorian calendar!
%
% Note that the beginning of a Julian Day is 12:00 UT (because astronomers
% wanted to avoid a date change during night - their observation time)
% Also note that in astronomical considerations, a year 0 exists which
% is identical to the year 1 before christ in the gregorianic calendar.
%
% Martin Knapmeyer, 21.08.1995

% gregorianisch/julianisch kalender bug fixed MK24.01.1999

% step 1
if (m==1)|(m==2)
   y=y-1;
   m=m+12;
end; % if m==1 or m==2

% step 2
a=fix(y/100);
if mkisgregory(y,m,d)==1
   b=2-a+fix(a/4);
else
   b=0;
end; % if mkisgregory

% step 3
res=fix(365.25*(y+4716))...
    +fix(30.6001*(m+1))...
    +d+b-1524.5;

% return result
jd=res;
