function [y,m,d]=mkjd2ymd(jd);
% mkjd2ymd.............compute year, month, day from Julian Day JD
%
% call: [y,m,d]=mkjd2ymd(jd);
%
%               jd: Julian Day (number of days since 01.01.-4712, 12:00)
%                   with decimal fraction
%
% result: y: year
%         m: month
%         d: day with decimal fraction, where .0 is 00:00
%         This is a date of the greogorian calendar.
%
%
% The result is valid por positive and negative years, but not for
% negative JD.
% Note that the beginning of a Julian Day is 12:00 UT (because astronomers
% wanted to avoid a date change during night - their observation time)
% Also note that in astronomical considerations, a year 0 exists which
% is identical to the year 1 before christ in the gregorianic calendar.
%
% Algorithm from:
%
% Jean Meeus, "Astronomische Algorithmen"
% Johann Ambrosius Barth, Leipzig, Berlin, Heidelberg
% 2. durchges. Auflage 1994
%
% DO NOT CHANGE THE ALGORITHM.
% DO NOT CHANGE THE MAGIC NUMBERS IN THE ALGORITHM.
%
% Martin Knapmeyer 23.01.1999

% preliminaries
jd=jd+0.5;

z=fix(jd);
f=jd-z;

if z<2299161
   a=z;
else
   alpha=fix((z-1867216.25)/36524.25);
   a=z+1+alpha-fix(alpha/4);
end; % if z


b=a+1524;
c=fix((b-122.1)/365.25);
d=fix(365.25*c);
e=fix((b-d)/30.6001);



% day
d=b-d-fix(30.6001*e)+f;


% month
if e<14
   m=e-1;
else
   m=e-13;
end; % if e<14


% year
if m>2
   y=c-4716;
else
   y=c-4715;
end; % if m<2
