function ymdhms=mky2ymdhms(years,mode);
% mky2ymdhms....convert number of years with decimal fractions into y/m/d/h/m/s
%
% call: ymdhms=mky2ymdhms(years);
%       ymdhms=mky2ymdhms(years,mode);
%
%
%       years: number of years, with decimal fractions
%
%       mode: sting defining the output format mode
%             available are:
%             'string': the output will be a string variable containing a
%                       prettyprinted y:m:d:h:m:s string
%             'number': the output will be a 6 elements vector 
%                       [y m d h m s]
%             DEFAULT: number
%
% result: ymdhms: string or vector containing y,m,d,h,m,s information
%                 formatted according to MODE.
%
% It is assumed that one year has 12 months, each 365.25/12 days long.
%
% Martin Knpameyer, 15.11.2005


%%% understand input
if nargin==1
    mode='number';
end; % if nargin


%%% decompose years into y,m,d,h,m,s
dayspermonth=365.25/12;
y=fix(years); % years
years=(years-y)*12;
m=fix(years); % months
years=(years-m)*dayspermonth;
d=fix(years); % days
years=(years-d)*24;
h=fix(years); % hours
years=(years-h)*60;
min=fix(years); % minutes
years=(years-min)*60;
s=years; % seconds
%%% done.

%%% now format it.
mode=lower(mode);
switch mode
    case {'number'}
         ymdhms=[y m d h min s];
    case {'string'}
         ymdhms=sprintf('%4.0dy %2.0dm %2.0dd %02.0d:%02.0d:%05.2f',y,m,d,h,min,s);
    otherwise
        error(['MKY2YMDHMS: unknown mode ' upper(mode)]);
end; % switch mode

