function [ymdhms,y,mn,d,h,mi,s]=mkydoy2ymdhms(year,doy);
% mkydoy2ymdhms...........compute y m d h m s from year and doy with fraction
%
% call: [ymdhms,y,mn,d,h,mi,s]=mkydoy2ymdhms(year,doy);
%
%       year: the year (four ciphers required!)
%       doy: the number of the day within YEAR, with decimal fractions
%            for the exact time
%            has to be positive and not exceed the number of days in
%            the given year. 
%            otherwise undefined behaviour !!
%            (that means: implosion of your cathode ray tube possible then).
%
% result: ymdhms: a string of the form yymmdd_hhmmss, as for EXTR_FILE
%                 (do you see the millenium bug? this format isn't my idea!)
%              y: the year, again
%              mn: the month
%              d: th day
%              h: hours
%              mi: minutes
%              s: seconds, with fractions
%
% Martin Knapmeyer, 17.09.1997
%
% BUGS: no plausibility test for DOY
%       seconds may be "60" in some cases (example: compare
%                 [ymdhms,y,mn,d,h,mi,s]=mkydoy2ymdhms(1999,35.4) and
%                 [ymdhms,y,mn,d,h,mi,s]=mkydoy2ymdhms(1999,100.4)
%       this problem is because 0.4 is 2/5 and cannot be represented in binary
%       digits. No idea how to fix. If problems with times occur, be sure that
%       minutes and seconds are not "60" and that the output string sontains
%       the correct minutes.


wholedoy=fix(doy); % whole days in DOY
fracdoy=doy-wholedoy; % fractional part of DOY

sec=fracdoy*86400; % fractional part of DOY in seconds

% day and month
[day,month]=mkdatebyno(wholedoy,year);



% h,m,s
hour=fix(sec/3600);
sec=sec-hour*3600;
minute=fix(sec/60);
sec=sec-minute*60;
second=sec;


% string output: construct yymmdd_hhmmss
yy=int2str(year);
yy=yy(3:4); % change this into yy=yy(1:4) to be millenium compatible
mm=int2str(month);
if length(mm)<2
   mm=['0' mm];
end; % if length(mm)
dd=int2str(day);
if length(dd)<2
   dd=['0' dd];
end; % if length(dd)
hh=int2str(hour);
if length(hh)<2
   hh=['0' hh];
end; % if length(hh);
mi=int2str(minute);
if length(mi)<2
   mi=['0' mi];
end; % if length(mi)
ss=int2str(fix(second));
if length(ss)<2
   ss=['0' ss];
end; % if length(ss)
ymdhms=[yy mm dd '_' hh mi ss]; % used for filename construction! do not alter!


% return results
ymdhms=ymdhms;
y=year;
mn=month;
d=day;
h=hour;
mi=minute;
s=second;
