function [seconds,jdzero]=mkymdhms2rjd(ymdhms,refday);
% mkymdhms2rjd..........compute number of seconds since 1.1.1996, 00:00:00
%
% call: seconds=mkymdhms2rjd(ymdhms,refday);
%       [seconds,jdzero]=mkymdhms2rjd(ymdhms,refday);
%
%            ymdhms: (numeric array)
%                    vector containing a time
%                    ymdhms(1): year
%                    ymdhms(2): month
%                    ymdhms(3): day
%                    ymdhms(4): hour
%                    ymdhms(5): minute
%                    ymdhms(6): second with decimal fractions
%
%            refday: (numeric array)
%                    vector containing a reference day in [y m d] format
%                    result time is in seconds since that day, 00:00:00.
%                    default: 01.01.1996
%
% result: seconds: seconds since the reference day, with decimal fractions
%         jdzero: the julian day of the reference day: the zero point of the relative
%                 timeaxis.
%
% this relative time is used for timeaxis computation by MKREADPDAS, MKREADPITSA
% MKPLOTSECTION, MKGFZTT
%
% Martin Knapmeyer 18.02.1998

%%% understand input
if nargin==1
    refday=[1996 1 1];
end; % if nargin


jdzero=mkjd(refday(1),refday(2),refday(3)); % value for 1.1.1996: 24500835


day=ymdhms(3)+ymdhms(4)/24+ymdhms(5)/1440+ymdhms(6)/86400;
seconds=(mkjd(ymdhms(1),ymdhms(2),day)-jdzero)*86400;
