function mklsgriditerdemotri(miniter,maxiter);
% mklsgriditerdemnotri....demonstrate iteration behaviour
%
% call: mklsgriditerdemotri(miniter,maxiter);
%
%
%       miniter: minimum number of iterations after which the grids are
%                plotted.
%       maxiter: maximum number of iterations to be applied to each base
%                grid. Be careful when making this larger than 3.
%
% result: none
%
% This demo generates and plots the first few iterations of grids based on
% tetrahedron, octahedron and icosahedron.
%
% Martin Knapmeyer, 21.12.2004


%%% prepare figure
figure(gcf);
clf;

%%% base grids to demonstrate
gridbases=strvcat('tetrahedron','octahedron','icosahedron');
baseanz=size(gridbases,1); % number of base grids



%%% loop over base grids
plotindex=0;
for gridcnt=1:baseanz
    
    %%% generate LSOPT structure
    currentbase=deblank(gridbases(gridcnt,:));
    lsopt=mklsopt('planet_radius',1,...
                  'grid_base',currentbase,...
                  'grid_init_minr',0,...
                  'grid_init_maxr',1,...
                  'grid_init_dr',7000,...
                  'grid_init_wdt',10,...
                  'iter_circmin',0);
             
    %%% generate base grid
    mygrid=mklsgridnew(lsopt);
              
    %%% loop over iteration number
    for iter=0:maxiter
        
        %%% iterate grid
        if iter>0
           mygrid=mklsgridmodify(lsopt,mygrid,[],'iterate',1);
        end; % if iter
        
        %%% plot grid
        if iter>=miniter
            
            plotindex=(iter-miniter)*baseanz+gridcnt; %(gridcnt-1)*maxiter+iter; %plotindex+1;
            subplot((maxiter-miniter)+1,baseanz,plotindex);
            title([currentbase ', iteration ' int2str(iter)]);
            handle=mklsgridplot(lsopt,mygrid,'surface');
            set(handle,'LineWidth',0.1); % edge line width
            alpha(1);
            view(-12,21);
            drawnow;
        
            %%% export grid nodes into ASCII file
            %%% this is routinely deactivated, but sometimes somebody comes
            %%% along who wants to know grid points...
            doexport=1;
            if doexport
               filename=[currentbase '_iteration_' int2str(iter) '.txt'];
               mklsgridexport(lsopt,mygrid,filename);
            end; % if doexport
            
            
        end; % if iter>miniter
       
        
    end; % for iter
    
end; % for gridcnt



