function mklszoptimtestsurf(sampleanz,maxstepsize,savefile);
% mklszoptimtestsurf..... driver to run MKLSZOIPTIMTEST 
%
% call: mklszoptimtestsurf(sampleanz,maxstepsize,savefile);
%
%       sampleanz: (number) [counter]
%                  number of samples in the random stair function
%
%       maxstepsize: (number) [counter]
%                  maximum step size of the random stair functions
%
%       savefile: (string)
%                  string containging path and file name at which the
%                  results are stored
%
% result: none
%
% This routine varies the number of initial samples and the
% iter_vertical_matchthresh parameter of the 1D depth samping routine.
% For each parameter pair, a number of runs is carried out and evaluated
% statistically. The statitics is plotted as function of the control
% paramaters.
% Since this take several hours, the results are stored in the specified
% file regularly. If the computer crashes during the run, just restart with
% the same parameters, the program reloads the last file and continues.
%
% This routine was used to conduct the test computations used for the
% optimization of the depth samplking in LOCSMITH.
%
% Martin Knapmeyer, 17.05.2006

%%% this was not intended to be part of the LOCSMITH distribution in the
%%% beginning, so it is written a bit quick-and-dirty.



nlist=sort([1 2 4 8 16 32 64 128 10:10:120]);%sort(38:52);
matchthreshlist=[1:10:100 100]; %0:10:100; % 80:2:100; %0:10:100;
runs=500;
drmin=2;



medianeff=zeros(length(matchthreshlist),length(nlist));
meaneff=medianeff;
stderreff=medianeff;
medianrely=medianeff;
meanrely=medianeff;
failrate=medianeff;
stderrrely=medianeff;
[ixe,ypse]=meshgrid(nlist,matchthreshlist);


%savefile='/scr_europa/zoptimtestsurf_step4_drmin2.mat';
if exist(savefile,'file');
   %%% load file
   dmy=load(savefile);
   %%% overwrite step function parameters to maintain consistency
   if mkexistfield(dmy,'sampleanz')
      sampleanz=dmy.sampleanz;
      maxstepsize=dmy.maxstepsize;
   end; % if mkexistfield(dmy,'sampleanz')
   %%% insert file content into matrices defined above.
   %%% this will be an error if the x and y coordinates used in the file
   %%% do not exist in the new matrices.
   %%% But it is not assumed that teh filed variables are subarrays of the
   %%% new ones.
   %%% this insertioni is thought for the case of a parameter range
   %%% extension.
   for matchthreshcnt=1:size(ixe,1)
      for ncnt=1:size(ixe,2)
          indies=find((ixe(matchthreshcnt,ncnt)==dmy.ixe)&...
                      (ypse(matchthreshcnt,ncnt)==dmy.ypse));
          if ~isempty(indies)
             medianeff(matchthreshcnt,ncnt)=dmy.medianeff(indies);
             meaneff(matchthreshcnt,ncnt)=dmy.meaneff(indies);
             stderreff(matchthreshcnt,ncnt)=dmy.stderreff(indies);
             medianrely(matchthreshcnt,ncnt)=dmy.medianrely(indies);
             meanrely(matchthreshcnt,ncnt)=dmy.meanrely(indies);
             stderrrely(matchthreshcnt,ncnt)=dmy.stderrrely(indies);
          else
              disp(['ZOPTIMTESTSURF: not inserted: ',...
                    'ixe=',num2str(ixe(matchthreshcnt,ncnt)),...
                    ', ypse=',num2str(ypse(matchthreshcnt,ncnt))]);
          end; % if ~isempty(indies)
      end; % for ncnt
   end; % for matchthreshlist
   
end; % if exist


figure(gcf);
clf;



for matchthreshcnt=length(matchthreshlist):-1:1
    
    for ncnt=1:length(nlist)
        
        evaluatethis=(medianeff(matchthreshcnt,ncnt)==0)||(isinf(meanrely(matchthreshcnt,ncnt)));
        if evaluatethis
            %%% compute only if not yet present in result matrix!
            
%             disp(['ZOPTIMTESTSURF: compute for matchthreshcnt=' int2str(matchthreshcnt),...
%                   ', ncnt=' int2str(ncnt)]);
%             disp(['ZOPTIMTESTSURF: old values: medianeff=' num2str(medianeff(matchthreshcnt,ncnt)),...
%                   ', meanrely=' num2str(meanrely(matchthreshcnt,ncnt))]);
            
            [efficiency,reliability]=mklszoptimtest(sampleanz,maxstepsize,...
                                                    matchthreshlist(matchthreshcnt),...
                                                    (0:(1/nlist(ncnt)):1)*700,...
                                                    drmin,...
                                                    runs,...
                                                    'off');

            failrate(matchthreshcnt,ncnt)=length(find(reliability<100))/runs;
            medianeff(matchthreshcnt,ncnt)=median(efficiency);
            meaneff(matchthreshcnt,ncnt)=mean(efficiency);
            stderreff(matchthreshcnt,ncnt)=std(efficiency)/sqrt(runs);
            medianrely(matchthreshcnt,ncnt)=median(reliability);
            meanrely(matchthreshcnt,ncnt)=mean(reliability);
            stderrrely(matchthreshcnt,ncnt)=std(reliability)/sqrt(runs);
            
%             disp(['ZOPTIMTESTSURF: new values: medianeff=' num2str(medianeff(matchthreshcnt,ncnt)),...
%                   ', meanrely=' num2str(meanrely(matchthreshcnt,ncnt))]);
%             disp(' ');

           
           save(savefile,...
                'sampleanz','maxstepsize',...
                'ixe','ypse',...
                'failrate',...
                'medianeff','meaneff','stderreff',...
                'medianrely','meanrely','stderrrely');
           
           
    %         disp(['saved for: matchthreshcnt=' int2str(matchthreshcnt),...
    %               ', ncnt= ' int2str(ncnt)]);

           
        end; % if costsavesurf(matchthreshcnt,ncnt)==0
        
        
        %%% plotting stuff
        
            clf;
    
            subplot(2,3,1); %figure(1)
            surf(ixe,ypse,medianeff);
            ylabel('matchthresh');
            xlabel('initial intervals');
            zlabel('median Efficiency [%]');
            title(['Steps: ' int2str(sampleanz) ', stepsize<=' int2str(maxstepsize),...
                   ', Runs: ' int2str(runs) ', drmin: ' num2str(drmin)]);
            mkfiatlux('on');
            lighting phong
            shading interp
            material dull
            axis([ min(nlist) max(nlist) min(matchthreshlist) max(matchthreshlist) 0 100]);
            view(40,30);
            drawnow;
            
            subplot(2,3,2); %figure(2);
            surf(ixe,ypse,abs(medianeff-meaneff));
            ylabel('matchthresh');
            xlabel('initial intervals');
            zlabel('abs(median-mean) Efficiency');
            title(['Steps: ' int2str(sampleanz) ', stepsize<=' int2str(maxstepsize),...
                   ', Runs: ' int2str(runs) ', drmin: ' num2str(drmin)]);
            mkfiatlux('on');
            lighting phong
            shading interp
            material dull
            axis([ min(nlist) max(nlist) min(matchthreshlist) max(matchthreshlist) 0 10]);
            view(40,30);
            drawnow;
            
            subplot(2,3,3); %figure(3);
            surf(ixe,ypse,stderreff);
            ylabel('matchthresh');
            xlabel('initial intervals');
            zlabel('Std. Err. Efficiency [%]');
            title(['Steps: ' int2str(sampleanz) ', stepsize<=' int2str(maxstepsize),...
                   ', Runs: ' int2str(runs) ', drmin: ' num2str(drmin)]);
            mkfiatlux('on');
            lighting phong
            shading interp
            material dull
            axis([ min(nlist) max(nlist) min(matchthreshlist) max(matchthreshlist) 0 10]);
            view(40,30);
            drawnow;
            
            subplot(2,3,4); %figure(4);
            surf(ixe,ypse,meanrely);
            ylabel('matchthresh');
            xlabel('initial intervals');
            zlabel('mean Reliability [%]');
            title(['Steps: ' int2str(sampleanz) ', stepsize<=' int2str(maxstepsize),...
                   ', Runs: ' int2str(runs) ', drmin: ' num2str(drmin)]);
            mkfiatlux('on');
            lighting phong
            shading interp
            material dull
            axis([ min(nlist) max(nlist) min(matchthreshlist) max(matchthreshlist) 0 100]);
            view(-40,30);
            drawnow;
            
            subplot(2,3,5); %figure(5);
            surf(ixe,ypse,abs(meanrely-medianrely));
            ylabel('matchthresh');
            xlabel('initial intervals');
            zlabel('abs(median-mean) Reliability');
            title(['Steps: ' int2str(sampleanz) ', stepsize<=' int2str(maxstepsize),...
                   ', Runs: ' int2str(runs) ', drmin: ' num2str(drmin)]);
            mkfiatlux('on');
            lighting phong
            shading interp
            material dull
            axis([ min(nlist) max(nlist) min(matchthreshlist) max(matchthreshlist) 0 10]);
            view(-40,30);
            drawnow;
            
            subplot(2,3,6); %figure(3);
            surf(ixe,ypse,stderrrely);
            ylabel('matchthresh');
            xlabel('initial intervals');
            zlabel('Std. Err. Reliability [%]');
            title(['Steps: ' int2str(sampleanz) ', stepsize<=' int2str(maxstepsize),...
                   ', Runs: ' int2str(runs) ', drmin: ' num2str(drmin)]);
            mkfiatlux('on');
            lighting phong
            shading interp
            material dull
            axis([ min(nlist) max(nlist) min(matchthreshlist) max(matchthreshlist) 0 10]);
            view(-40,30);
            drawnow;

        
    end; % for ncnt
    
end; % for matchthreshcnt