function y=mkstepfunction(x,jumpx,jumpy,mode);
% mkstepfunction.........generalized step function evaluation
%
% call: y=mkstepfunction(x,jumpx,jumpy);
%         y=mkstepfunction(x,jumpx,jumpy,mode);
%
%         x: free variable of the step function
%         jumpx: positions of the steps on the x-axis
%         jumpy: function values at JUMPX
%
%         mode: string that determines how to interpret the jumps:
%               'absolute': JUMPY defines function values
%               'gradient': JUMPY defines change of function
%               default: 'absolute'
%
% result: y: function value at X
%
% Thsi routine implements a generalized step function which is defined by a
% list of step positions and function values at these positions. The
% function remains constant as long as x is smaller than the x of the next
% step.
% For x smaller than the first value in JUMPX, the function is zero.
% For x larger than the last jump, the function remains at the last level
% defined in JUMPX.
%
% Martin Knapmeyer, 2005


%%% dummy test
% %%% define positions of function jumps
% jumpx=[0 2 3 4 5];
% 
% %%% define function value for x larger than last jumpx
% jumpy=[3 1 6 2 4];


%%% understand input & set defaults
switch nargin
    case {3}
        mode='absolute';
    case {4}
        switch mode
            case {'absolute'}
                %%% nothing happens
            case {'gradient'}
                %%% compute absolute value JUMPY from gradient
                jumpy=cumsum(jumpy);
            otherwise
                error(['MKSTEPFUNCTION: unknown mode ' upper(mode)]);
        end; % switch mode
    otherwise
        error('MKSTEPFUNCTION: illegal number of input arguments!');
end; % switch nargin


%%% find out in which interval we are
y=x*0;
for xindy=1:length(x)
    indies=find(x(xindy)>=jumpx);
    if ~isempty(indies)
       %%% we're somewhere right of the xindy-th jump
       interval=indies(end);
       y(xindy)=jumpy(interval);
    else
       %%% we're left of the first jump, function is assumed to be zero here
       y(xindy)=0;
    end; % if ~isempty(indies)
end; % for xindy

