function [x,y,z]=mkfastsph2cart(az,elev);
% mkfastsph2cart......spherical to cartesian transformation
%
% call: [x,y,z]=mkfastsph2cart(az,elev);
%
%               az: azimuth angle (= longitude) [radian]
%             elev: elevation angle (=latitude) [radian]
%
% result: x,y,z: the corresponding cartesian coordinates
%
% This is an abridged version of matlab's sph2cart version. It does not use
% the radius coordinate, since this is in many cases not important. It also
% tries to reduce the number of operations.
%
% This seems to be about 30% faster than the original, but is invalid if
% the radius coordinate is relevant for you.
%
% Martin Knapmeyer, 04.11.2004


z=sin(elev);
elev=cos(elev); % elev is not needed any longer, and by reusing it we avoid
                % the allocation of new memory. tricky, but faster.
x=elev.*cos(az);
y=elev.*sin(az);
