function phaseindex=mklsfxdgetphase(fxd,phase);
% mklsfxdgetphase.......find index of phase with given indentifier in FXD
%
% call: phaseindex=mklsfxdgetphase(fxd,phase);
%
%                fxd: (strcuture array)
%                     FXD structure containing a single station description
%              phase: (string)
%                     Seismic Phase name string
%
% result: phaseindex: (number)
%                   index of the phase with name PHASE within the FXD
%                   structure.
%                   If no such phase exists, PHASEINDEX is empty.
%
% This routine searches only for phase names wihtin a single element of an
% FXD array! Be sure that size(fxd) is 1-by-1!
%
% Martin Knapmeyer, 04.02.2005


%%% init result
phaseindex=[];


%%% loop over all stations until the right one is found
if ~isempty(fxd.phase)
    %%% if the phase list is empty, we do not need to search!
    fxdlen=length(fxd); % number of stations in FXD
    done=0;
    cnt=1;
    while done==0
        if cnt<=fxdlen
            %%% is this the right one?
            if strcmp(deblank(fxd.phase(cnt,:)),phase)==1
                %%% station found!
                phaseindex=cnt;
                done=1;
            else
                cnt=cnt+1;
            end; % if strcmp(fxd(cnt).phase,phase)==1
        else
            %%% nothing found and end of list reached - quit.
            done=1;
        end; % if cnt<=fxdlen
    end; % while
end; % if ~isempty(fxd.phase)