function [newgrid,newttsupport]=mklsgridevalat(lsopt,mygrid,fxd,evalthese,ttsupport);
% mklsgridevalat......evaluate arrvial time of nodes
%
% call: [newgrid,newttsupport]=mklsgridevalat(lsopt,mygrid,fxd,evalthese,ttsupport);
%
%       lsopt: (structure)
%              LSOPT structure as returned by MKLSOPT
%
%       mygrid: (structure)
%              grid structure as returned by MKLSGRIDNEW
%
%       fxd: (strcuture)
%                   FXD structure as returned by MKLSLS2FXD, containing all
%                   data.
%
%       evalthese: (structure)
%              structure denoting grid nodes to be evaluated, as returned
%              by MKLSGRIDNONREADY.
%
%       ttsupport: (structure)
%                  TTSUPPORT structure. This structure might be as returned
%                  by MKLSEMPTYTTSUPPORT, i.e. unspecific, or with fields
%                  that are specific for the used travel time software.
%
%
% result: newgrid: (structure)
%                  as MYGRID, but with actualized tested-counters and
%                  fit-field.
%
%         newttsupport: (structure)
%                  as TTSUPPORT, but with actualized contents.
%
% NOTE that all input and output structures have different contents
% depending on the grid type defined in MYGRID.TYPE!
%
% This routine is derived from MKLSGRIDEVALBAZ.
%
% Martin Knapmeyer, 30.03.2005



%%% init result
atidlist=[];

%%% verbosity
verbosity=2;

%%% is there any arrival time data in FXD? if yes, dispatch to grid
%%% specific routines, if not, quit.
fxdlen=length(fxd);
atcnt=0;
for indy=1:fxdlen
    atcnt=atcnt+fxd(indy).atcnt;
end; % for indy

if strcmp(lsopt.eval_at,'on')==1
    
    %%% AT evaluation is switched on, so do it if data exists!
    mklsverbose(verbosity+1,lsopt,'MKLSGRIDEVALAT: arrival time evaluation is switched ON.');

    if atcnt>0

        %%% say hello
        mklsverbose(verbosity,lsopt,'MKLSGRIDEVALAT: start arrival time evaluation.');

        %%% dispatch work to grid specific routines
        gridtype=lower(mygrid.type);
        switch gridtype
            case {'cartesian'}
                newgrid=grid;
                mklsnotyet('warn');
                newgrid=mygrid;
                newttsupport=ttsupport;
                atidlist=NaN;
            case {'triangular'}
                [newgrid,newttsupport]=mklsgridevalattri(lsopt,mygrid,fxd,evalthese,ttsupport);
            otherwise
                error(['MLSGRIDEVALAT: unknown grid type ' upper(gridtype)]);
        end; % switch gridtype

        %%% say goodbye!
        mklsverbose(verbosity,lsopt,'MKLSGRIDEVALAT: arrival time evaluation completed.');

    else
        mklsverbose(verbosity,lsopt,'MKLSGRIDEVALAT: no Arrival Time Data!');
        newgrid=mygrid;
        newttsupport=ttsupport;
    end; % if bazcnt>0

else
    %%% AT evaluation is switched off
    mklsverbose(verbosity+1,lsopt,'MKLSGRIDEVALAT: back azimuth evaluation is switched OFF.');
    newgrid=mygrid;
    newttsupport=ttsupport;
    
end; % if strcmp(lsopt.eval_baz,'on')==1