function newgrid=mklsgridevalbaz(lsopt,mygrid,fxd,evalthese);
% mklsgridevalbaz......evaluate back azimuth of nodes
%
% call: newgrid=mklsgridevalbaz(lsopt,mygrid,simpledata,evalthese);
%
%       lsopt: (structure)
%              LSOPT structure as returned by MKLSOPT
%
%       mygrid: (structure)
%              grid structure as returned by MKLSGRIDNEW
%
%       fxd: (strcuture)
%                   FXD structure as returned by MKLSLS2FXD, containing all
%                   data.
%
%       evalthese: (structure)
%              structure denoting grid nodes to be evaluated, as returned
%              by MKLSGRIDNONREADY.
%
% result: newgrid: (structure)
%                  as MYGRID, but with actualized tested-counters and
%                  fit-field.
%
% NOTE that all input and output structures have different contents
% depending on the grid type defined in MYGRID.TYPE!
%
% Martin Knapmeyer, 23.02.2005, 28.02.2005



%%% init result
bazidlist=[];

%%% verbosity
verbosity=2;

%%% is there any back azimuth data in FXD? if yes, dispatch to grid
%%% specific routines, if not, quit.
fxdlen=length(fxd);
bazcnt=0;
for indy=1:fxdlen
    bazcnt=bazcnt+fxd(indy).bazcnt;
end; % for indy

if strcmp(lsopt.eval_baz,'on')==1
    
    %%% BAZ evaluation is switched on, so do it if data exists!
    mklsverbose(verbosity+1,lsopt,'MKLSGRIDEVALBAZ: back azimuth evaluation is switched ON.');

    if bazcnt>0

        %%% say hello
        mklsverbose(verbosity,lsopt,'MKLSGRIDEVALBAZ: start back azimuth evaluation.');

        %%% dispatch work to grid specific routines
        gridtype=lower(mygrid.type);
        switch gridtype
            case {'cartesian'}
                newgrid=grid;
                mklsnotyet('warn');
                newgrid=mygrid;
                bazidlist=NaN;
            case {'triangular'}
                newgrid=mklsgridevalbaztri(lsopt,mygrid,fxd,evalthese);
            otherwise
                error(['MLSGRIDEVALBAZ: unknown grid type ' upper(gridtype)]);
        end; % switch gridtype

        %%% say goodbye!
        mklsverbose(verbosity,lsopt,'MKLSGRIDEVALBAZ: back azimuth evaluation completed.');

    else
        mklsverbose(verbosity,lsopt,'MKLSGRIDEVALBAZ: no Back Azimuth Data!');
        newgrid=mygrid;
    end; % if bazcnt>0

else
    %%% BAZ evaluation is switched off
    mklsverbose(verbosity+1,lsopt,'MKLSGRIDEVALBAZ: back azimuth evaluation is switched OFF.');
    newgrid=mygrid;
    
end; % if strcmp(lsopt.eval_baz,'on')==1