function [newgrid,newttsupport]=mklsgridevaldt(lsopt,mygrid,fxd,evalthese,ttsupport);
% mklsgridevaldt......evaluate differential travel times of nodes
%
% call: [newgrid,newttsupport]=mklsgridevaldt(lsopt,mygrid,simpledata,evalthese,ttsupport);
%
%       lsopt: (structure)
%              LSOPT structure as returned by MKLSOPT
%
%       mygrid: (structure)
%              grid structure as returned by MKLSGRIDNEW
%
%       fxd: (strcuture)
%                   FXD structure as returned by MKLSLS2FXD, containing all
%                   data.
%
%       evalthese: (structure)
%              structure denoting grid nodes to be evaluated, as returned
%              by MKLSGRIDNONREADY.
%
%       ttsupport: (structure)
%                  TTSUPPORT structure. This structure might be as returned
%                  by MKLSEMPTYTTSUPPORT, i.e. unspecific, or with fields
%                  that are specific for the used travel time software.
%
% result: newgrid: (structure)
%                  as MYGRID, but with actualized tested-counters and
%                  fit-field.
%
%         newttsupport: (structure)
%                  as TTSUPPORT, but with actualized contents.
%
% NOTE that all input and output structures have different contents
% depending on the grid type defined in MYGRID.TYPE!
%
% Martin Knapmeyer, 14.06.2005

%%% verbosity
verbosity=2;


if strcmp(lsopt.eval_dt,'on')==1
    
    %%% DT evaluation is switched on, so do it if data exists!
    mklsverbose(verbosity+1,lsopt,'MKLSGRIDEVALDT: Differential Travel Time evaluation is switched ON.');

    mklsnotyet('warn');
    
    newgrid=mygrid;
    newttsupport=ttsupport;

else
    %%% DT evaluation is switched off
    mklsverbose(verbosity+1,lsopt,'MKLSGRIDEVALDT: Differential Travel Time evaluation is switched OFF.');
    
    newgrid=mygrid;
    newttsupport=ttsupport;
    
end; % if strcmp(lsopt.eval_baz,'on')==1