function [incomp,incomplist]=mklsgridevalincomp(mygrid);
% mklsgridevalincomp........test degree of data compatibility of grid
%
% call: [incomp,incomplist]=mklsgridevalincomp(mygrid);
%
%       mygrid: (structure array)
%               LOCSMITH search grid as returned by MKLSGRIDNEW.
%
% result: incomp: (number) [counter]
%                 Degree of incompatibility of data.
%                  0: data fully compatible at some nodes.
%                 >0: best fitting node is not compatible with INCOMP data
%
%         incomplist: (numeric array) [counter]
%                 Degree of incompatibility of the individual layers.
%                 incomplist(i,2) is the incompatiblity degree of layer
%                 with ID incomplist(i,1).
%                 This can be used to determine which layers may be
%                 removed.
%
%
% A node that is acceptable as earthquake hypocenter should be compatible
% with all observed data. If there are observations no node is compatible
% with, these data might be outliers, or there is another reason that makes
% a fully consitens location impossible (e.g. layer not in possible hypocenter depth,
% or, more seriusly, wrong velocity model).
% This routine determines how many of such "outlier" data exist.
%
% Martin Knapmeyer, 16.03.2005, 26.04.2007


%%% loca verbosity
verbosity=0;

%%% init result
incomp=[];

%%% how many layers?
layeranz=length(mygrid.layers);

%%% list to collect results from all layers
incomplist=zeros(layeranz,2);

%%% loop over all layers
for indy=1:layeranz
    
    %%% test plausibility of .tested field: all nodes have to be tested
    %%% against the same number of data!
    testplausibility=sum(diff(mygrid.layers(indy).tested(:,2)));
    if testplausibility~=0
       dmylsopt=mklsopt('verbosity',0);
       mklsverbose(verbosity,dmylsopt,'MKLSGRIDEVALINCOMP: some nodes were not tested against all data!');
       %error(['MKLSGRIDEVALINCOMP: some nodes were not tested against all data!']);
    end; % if testplausibility
    
    %%% max number of tests applied to nodes of this layer
    testnum=max(mygrid.layers(indy).tested(:,2));
    
    %%% max number of compatible data in this layer
    bestfit=max(mygrid.layers(indy).fit(:,2));
    
    %%% the incompatibility of this layer is the difference between number
    %%% of tests applied and max compatible data
    incomplist(indy,1)=mygrid.layers(indy).id;
    incomplist(indy,2)=testnum-bestfit;
    
end; % for indy

%%% The resulting incompatibility is the MINIMUM of the incomplist: some
%%% layers may be totally incompatible simply because they are in the wrong
%%% depth. Such layers will always have large incompatiblity while there
%%% may be fully compatible layers in the same grid!
incomp=min(incomplist(:,2));
