function tt=mklssinglett(lsopt,phase,f1,f2,f3,s1,s2,s3);
% mklssinglett......compute traveltime for single focus/station pair
%
% call: tt=mklssinglett(lsopt,phase,f1,f2,f3,s1,s2,s3);
%
%          lsopt: (structure)
%                 LOCSMITH options structure as returned by MKLSOPT
%
%           phase: (string)
%                 seismic phase for which a travel time is desired
%
%           f1,f2,f3: (numbers)
%                 three coordinates describing the position of the
%                 hypocenter. Meaning and dimension of these coordinates
%                 depend on grid type.
%
%                 With a triangular grid and the TTBOX software as external
%                 travel time calculator, the meaning is as follows:
%                 f1: hypocenter longitude [deg]
%                 f2: hypocenter latitude [deg]
%                 f3: hypocenter depth [km]
%
%           s1,s2,s2: (numbers)
%                 threee soordinates describing the position of the
%                 station. Meaning and dimension of these coordinates
%                 depend on grid type.
%
%                 With a triangular grid and the TTBOX software as external
%                 travel time calculator, the meaning is as follows:
%                 f1: station longitude [deg]
%                 f2: station latitude [deg]
%                 f3: station elevation [km] (ignored!)
%
% result: tt: (numeric) [s]
%             travel time(s) for the desired phase from point (f1,f2,f3) to
%             point (s1,s2,s3)
%
% Martin Knapmeyer, 12.04.2005
%
% BUGS: when using TTBOX, the station elevation is currently ignored!



%%% switch to the different travel time packages
switch lower(lsopt.tt_package)
    
    %%%%%% TTBOX INTERFACE
    case {'ttbox'}
        
        
        %%% transform the CLR model struct given in the LSOPT into an ND
        %%% model acceptable for MKFINDP and MKTTQUICK
        velocitymodel=mkclr2model(lsopt.tt_options.model,...
                                  lsopt.tt_options.interpdz,...
                                  lsopt.tt_options.interpmode);


        %%% epicentral distance from hypocentre to station
        delta=mklsepidistv(f1,f2,s1,s2);

        %%% call TTBOX
        [tt,p]=mkttime(phase,delta,f3,velocitymodel);


         %%%%%%% END OF TTBOX INTERFACE
        
    
    %%%%%%% NO INTERFACE AVAILABLE ERROR
    otherwise
        error(['MKLSSINGLETT: no interface to ' upper(lsopt.tt_package) 'available']);
end; % switch lsopt.tt_package