function [cc,r]=mkcircumcircle(a,b,c);
% mkcircumcircle........compute circumcircle paramters of 3D triangle
%
% call: [cc,r]=mkcircumcircle(a,b,c);
%
%              a,b,c: (number triples)
%                     cartesian coordinates of triangle corners A, B, C
%                     a(1) is x coordinate of point A
%                     a(2) is y coordinate of point A
%                     a(3) is z coordinate of point A
%
%                     b, c analoguous.
%
% result: cc: (number triple)
%             cartesian coordinates of the circumcenter of triangle ABC
%             c(1) is x coordinate 
%             c(2) is y coordinate 
%             c(3) is z coordinate
%
%          r: (number)
%             radius of the circumcircle
%
%
% The circumcircle is the circle that is defined by the three corners of
% the triangle. Its center can be constructed as the point in which the
% perpendicular bisectors of all three sides of triangle ABC intersect.
% In this routine, only the bisectors of sides AB and BC are intersected.
% The radius is computed as distance between points CC and A.
%
% Martin Knapmeyer, 03.12.2004


%%% compute mid points of triangle sides AB and BC
d=0.5*(a+b); % mid point of side AB
e=0.5*(b+c); % mid point of side BC
%f=0.5*(c+a); % mid point of side CA


%%% compute directions of perpendicular bisectors of triangle sides Ab and BC
nab=mkperpvect(a-c,b-c); % perpendicular to side AB
nbc=mkperpvect(b-a,c-a); % perpendicular to side BC
%nca=mkperpvect(c-b,a-b); % perpendicular to side CA

%%% intersection of sides AB and BC
%%% perpendicular bisector of side AB is given by equation p=d+rho*nab
%%% perpendicular bisector of side BC is given by equation p=e+alpha*nbc
%%% CC is defined by equating these equations.
nmatrix=[nab(1) -nbc(1);...
         nab(2) -nbc(2)];
righthandside=[e(1)-d(1);...
               e(2)-d(2)];
rhoalpha=nmatrix\righthandside;
%%% evaluation of bisector of AB to get actual coordinates of CC
cc=d+rhoalpha(1)*nab;


%%% radius of circumcircle is given by distance between CC and A
r=sqrt(sum((cc-a).^2));


%%% plot everything
%%clf;
% lambda=[0 1];
% figure(1);
% hold on
% plot3([a(1) b(1) c(1) a(1)],[a(2) b(2) c(2) a(2)],[a(3) b(3) c(3) a(3)],'k.-');
% plot3([d(1) e(1)],[d(2) e(2)],[d(3) e(3)],'ko');
% px=d(1)+lambda*nab(1);
% py=d(2)+lambda*nab(2);
% pz=d(3)+lambda*nab(3);
% %plot3(px,py,pz,'r--');
% px=e(1)+lambda*nbc(1);
% py=e(2)+lambda*nbc(2);
% pz=e(3)+lambda*nbc(3);
% %plot3(px,py,pz,'r--');
% plot3(cc(1),cc(2),cc(3),'ks');
% hold off
%%drawnow;
%%% done with plotting

%%% and we're done.
return;