function [ccsph,rsph]=mkcircumcirclesph(a,b,c);
% mkcircumcirclesph......determine circumcircle parameters of a spherical triangle
%
% call: [ccsph,rsph]=mkcircumcirclesph(a,b,c);
%
%       a,b,c: (numeric doublets) [deg]
%              sphercial coordinates of points A, B, C that define a
%              spherical triangle. The radius of the sphere is assumed to
%              be 1.
%              a(1) is longitude of point A
%              a(2) is latitude of point A
%
%              b,c analoguous.
%
% result: cc: (numeric doublet) [deg]
%             spherical coordinates of circumcenter point
%             c(1) is longitude
%             c(2) is latitude
%             radius is implied to be 1.
%
%       rsph: (number) [deg]
%             radius of the circumcircle, given as angle on the unit
%             sphere. Thsi radius is computed as distance angle between CC
%             and point A.
%
% Computation uses the cartesian computation in MKCIRCUMCIRCLE: The circle
% as such is the same as in cartesian coordinates, only the center point
% and radius are different since they must define a small circle on a
% sphere.
%
% Martin Knapmeyer, 03.12.2004


%%% a useful constant
radian=pi/180;

%%% from deg to rad
%%% a not changed here because needed later in deg!
b=b*radian;
c=c*radian;

%%% cartesian coordinates of points A,B,C
[acart(1),acart(2),acart(3)]=mkfastsph2cart(a(1)*radian,a(2)*radian);
[bcart(1),bcart(2),bcart(3)]=mkfastsph2cart(b(1),b(2));
[ccart(1),ccart(2),ccart(3)]=mkfastsph2cart(c(1),c(2));

%%% cartesian circumcenter point
[cc]=mkcircumcircle(acart,bcart,ccart);

%%% spherical coordinates of the spherical circumcenter point
[ccsph(1),ccsph(2)]=cart2sph(cc(1),cc(2),cc(3));
ccsph=ccsph/radian; % from rad to deg

%%% distance angle between CCSPH and A
rsph=mklsepidist(ccsph(1),ccsph(2),a(1),a(2));


%%% that was simple, wasn't it?
%%% and we're done.