function id=mklscreateid(sizing);
% mklscreateid.......create ID numbers for layers, nodes etc.
%
% call: id=mklscreateid;
%       id=mklscreateid(sizing);
%
%          sizing: (numeric row vector)
%                  a size vector as returned by size(), defining the
%                  number of IDs to be created.
%                  This allows to create all IDs for a node array (for
%                  example) in one call.
%                  Default: [1 1]
%
% result: id: a unique (hopefully...) ID number to identify objects.
%             In some respect comparable to object handles in MatLab.
%             IDs are aways integer numbers.
%
% IDs are created uniform random numbers by calling rand()
% This should provied a sufficient stock of IDs. But since MatLab routinely
% initilaizes the random number generator with the same seed upon each
% startup, IDs may repeat when you call MKLSCREATEID in differnt MatLab
% sessions. It is recommended to re-initialize the random number generator
% after starting MatLab.
%
% Martin Knapmeyer, 09.09.2004, 16.09.2004
%
% BUG: the returned ID may be zero. A zero ID might cause problems
% elsewhere. But the probability for a zero is so small that I didn't catch
% that.


%%% understand input
if nargin==0
    sizing=[1 1];
end; % if nargin


%%% init result array
id=zeros(sizing);

%%% create IDs as random numbers
id=rand(sizing); %fix(rand(sizing)*mklsconstants('IDFactor'));