function mklsgridexporttri(lsopt,mygrid,filename);
% mklsgridexport.......export x/y/z coordinates of triangular grid points
%
% call: mklsgridexport(lsopt,mygrid,filename);
%
%              lsopt: (struct)
%                     LOCSMITH options structure as returned by MKLSOPT
%            
%               grid: (struct)
%                     a grid structure as returned by MKLSGRIDNEW.
%                     This grid will be refined according to the settings
%                     in the other parameters.
%
%           filename: (string)
%                     a string specifying a file name
%
%
% result: none
%
% The routine writes a file named FILENAME into the current directory (the
% working directory of MatLab), containing cartesian coordinates of a grid.
%
% The routine currently exports only the first layer of the grid (assuming
% that there is only one layer)
%
%
% The file contains:
% 1st line: number of points
% 2nd to n-th line: x y z coordinates of points
%
%
% NOTE that the routine alsways runs on verbosity level 1 to let you know
% that files are written!
%
% Martin Knapmeyer, 07.09.2006


%%% a useful constant
radian=pi/180;

%%% verbosity
verbosity=1;
lsopt.verbosity=1;


%%% test for number of layers
if length(mygrid.layers)~=1
   mklsverbose(verbosity,lsopt,...
               'MKLSGRIDEXPORTTRI: routine exports only one-layer grids. Sorry.');
   mklsnotyet('crash');
end; % if mygrid.layers~=1


%%% say hello
mklsverbose(verbosity,lsopt,'MKLSGRIDEXPORTTRI: start writing file ',filename);


%%% open file
[fid,msg]=fopen(filename,'w');
if fid==-1
   error(['MKLSGRIDEXPORTTRI: ' msg]);
end; % if fid


%%% write number of points
pointcnt=size(mygrid.layers.nodes,1);
fprintf(fid,'%d\n',pointcnt);


%%% determine median circumcircle radius of all triangles
tricnt=length(mygrid.layers.tri); % number of triangles
cclist=zeros(1,tricnt);
for triindy=1:tricnt
    cclist(triindy)=mygrid.layers.tri(triindy).cr;
end; % for triindy
mklsverbose(verbosity,lsopt,'MKLSGRIDEXPORTTRI: smallest circumcircle: ',...
            sprintf('%17.15f',min(cclist)),' degrees.');


%%% transform points from spherical to cartesian
[px,py,pz]=sph2cart(mygrid.layers.nodes(:,2)*radian,...
                    mygrid.layers.nodes(:,3)*radian,...
                    mygrid.layers.radius);


%%% write points
for pointindy=1:pointcnt
    fprintf(fid,...
            '%17.15f %17.15f %17.15f\n',...
            px(pointindy),...
            py(pointindy),...
            pz(pointindy));
end; % for pointindy



%%% close file
fclose(fid);

%%% say goodbye
mklsverbose(verbosity,lsopt,'MKLSGRIDEXPORTTRI: finished writing file ',filename);