function [idlist,maxfit]=mklsgridfindmatches(lsopt,mygrid);
% mklsgridfindmatches......find triangles whose nodes match all data
%
% call: idlist=mklsgridfindmatches(lsopt,mygrid);
%
%               lsopt: (struct)
%                      LOCSMITH options structure as returned by MKLSOPT
%              mygrid: (struct)
%                      LOCSMITH search grid as returned by MKGRIDNEW
%
% result: 
%              idlist: (struct array)
%                      A struture variable that defines the layers and
%                      triangles to be modified. The following fields are
%                      expected:
%                      .layer: (numeric)
%                              layer ID, only one per element of IDLIST.
%                      .triangle: (numeric array)
%                                 list of triangle IDs
%                                 if this is the empty matrix [], all
%                                 triangles are modified.
%
%                      idlist(i).layer defines a layer in which
%                      modifications on triangles shall be made. Then
%                      idlist(i).triangle is a list of triangle IDs that
%                      defines which triangles of the speicifed layer are to
%                      be modified.
%                      If n layers are to be modified, IDLIST must consist
%                      of n elements, each having its own .layer and
%                      .triangle fields.
%
%              maxfit: (array) [counter]
%                      list containing the maximum compatibility for each
%                      layer. maxfit(1) is for the first layer in the grid,
%                      maxfit(end) for the last one. (this is not
%                      necessarily in sequence of layer radius/depth!)
%
% This routine identifies all triangles that have nodes which match all
% data. This match is given when the .fit field of the node contains the
% same value as the corresponding .tested field.
%
% Martin Knapmeyer, 01.03.2005


%%% init result
idlist=[];


%%% dispatch grid types
switch mygrid.type
    case {'triangular'}
        [idlist,maxfit]=mklsgridfindmatchtri(lsopt,mygrid);
    case {'cartesian'}
        mklsnotyet('crash');
    otherwise
        error(['MKLSGRIDFINDMATCHES: unknown grid type ' upper(mygrid.type)]);
end; % switch mygrid.type