function [z,cofz,nodecnt]=mklsgridgetcofz(lsopt,mygrid);
% mklsgridgetcofz........get compatibility as function of depth/radius
%
% call: [z,cofz,nodecnt]=mklsgridgetcofz(lsopt,mygrid);
%
%
%       lsopt: (structure)
%               LOCSMITH options structure as returned by MKSLOPT.
%       mygrid: (strcutrue array)
%               LOCSMITH search grid as returned by MKLSGRIDNEW.
%
% result: z: (numeric array) [km]
%            List of depths/radii of all layers in MYGRID.
%            For triangular grids, this is a list of layer radii.
%            For cartesian grids, this is a list of layer depths below
%            surface.
%
%         cofz: (numeric array) [counter]
%               Compatibility as function of depth/radius
%               This gives the maximum compatibility of nodes with data for
%               each layer, i.e. the maximum compatibility value of each
%               layer.
%               cofz(i) is the compatibility at depth/radius z(i).
%               COFZ means "Compatibility as function OF Z".
%
%         nodecnt: (numeric array) [counter]
%               number of nodes at depth/radius z(i)
%
% Martin Knapmeyer, 27.06.2005



%%% verbosity
verbosity=4;


%%% say hello
mklsverbose(verbosity,lsopt,'MKLSGRIDGETCOFZ: compiling C(z) function');

%%% dispatch work to grid specific routines
gridtype=lower(mygrid.type);
switch gridtype
    case {'cartesian'}
        newgrid=grid;
        mklsnotyet('warn');
        z=[];
        cofz=[];
    case {'triangular'}
        [z,cofz,nodecnt]=mklsgridgetcofztri(lsopt,mygrid);
    otherwise
        error(['MLSGRIDGETCOFZ: unknown grid type ' upper(gridtype)]);
end; % switch gridtype

%%% say goodbye!
mklsverbose(verbosity,lsopt,'MKLSGRIDGETCOFZ: C(z) compilation completed.');