function [r,cofz,nodecnt]=mklsgridgetcofztri(lsopt,mygrid);
% mklsgridgetcofztri........get compatibility as function of radius
%
% call: [r,cofz,nodecnt]=mklsgridgetcofztri(lsopt,mygrid);
%
%       lsopt: (structure)
%               LOCSMITH options structure as returned by MKSLOPT.
%       mygrid: (strcutrue array)
%               triangular LOCSMITH search grid as returned by MKLSGRIDNEW.
%
% result: r: (numeric array) [km]
%            List of layer radii of all layers in MYGRID.
%            
%
%         cofz: (numeric array) [counter]
%               Compatibility as function of radius
%               This gives the maximum compatibility of nodes with data for
%               each layer, i.e. the maximum compatibility value of each
%               layer.
%               cofz(i) is the compatibility at radius r(i).
%               COFZ means "Compatibility as function OF Z".
%
%        nodecnt: (numeric array) [counter]
%               number of nodes at radius r(i)
%
% Martin Knapmeyer, 27.06.2005



%%% verbosity
verbosity=4;


%%% init result
layercnt=length(mygrid.layers); % number of layers in MYGRID
r=zeros(layercnt,1);
cofz=zeros(layercnt,1);
nodecnt=zeros(layercnt,1);


%%% collect data
for indy=1:layercnt
    r(indy)=mygrid.layers(indy).radius;
    cofz(indy)=max(mygrid.layers(indy).fit(:,2));
    nodecnt(indy)=size(mygrid.layers(indy).fit,1);
    
    mklsverbose(verbosity,lsopt,'MKLSGRIDGETCOFZTRI: ',...
                'R=',r(indy),...
                'compatibility=',cofz(indy));
end; % for indy