function [rownum,nodes]=mklsgridgetnodetri(id,layer);
% mklsgridgetnodetri..........return node with specified ID
%
% call: [rownum,nodes]=mklsgridgetnodetri(id,layer);
%
%              id: (number) ID number of requested node
%              layer: (struct) layer structure as returned by MKLSGRIDNEWTRILAYER
%
% result: rownum: row number of node specified by ID in the .nodes array
%                 of the given layer
%                 empty if no such node exists.
%          nodes: the requested node itself, including the ID.
%                 nodes is thus a 3-element row vector as specified in
%                 mklsgridnewtrilayer.
%                 empty if node ID does not exist.
%
%
% Martin Knapmeyer, 13.09.2004




% %%% init result
% rownum=[];
% nodes=[];


%%% find all rows with requested ID
rownum=find(layer.nodes(:,1)==id); %,1,'first');
rowcnt=length(rownum);
switch rowcnt
    case {0}
        %%% requested node does not exist, return empty
        rownum=[];
        nodes=[];
    case {1}
        %%% requested node found, return it
        nodes=layer.nodes(rownum,:);
    otherwise
        error(['MKLSGRIDGETNODETRI: non-unique node ID: ' int2str(id),...
               ': ' int2str(rowcnt) ' nodes with this ID!']);
end; % switch rowcnt




