function triids=mklsgridgettriangle(nodeid,layer);
% mklsgridgettriangle.....identify triangles that use given nodes
%
% call: triids=mklsgridgettriangle(nodeid,layer);
%
%              nodeid: (numeric array)
%                      list of node IDs
%
%              layer:  (struct)
%                      layer structure containing all triangles, nodes
%                      etc.
%
% result: triids: (numeric array)
%                 unique list of triangle IDs
%
% The routine identifies all triangles that use at least one of the nodes
% identified by NODEID and returns the IDs of these triangles. Together with
% MKLSGRIDNODEONENDGETRI, this can be used to identify all neighbours of a
% given triangle.
%
% Martin Knapmeyer, 05.11.2004


%%% init result
triids=[];

%%% number of nodes in list
nodeanz=length(nodeid);

%%% number of triangles in layer
trianz=length(layer.tri); 


%%% loop over all triangles
for tricnt=1:trianz
    %%% loop over all nodes
    for nodecnt=1:nodeanz
        %%% test only if triangle has nodes as children
        switch layer.tri(tricnt).childtype
            case {'node'}
                 indy=find(layer.tri(tricnt).nodes==nodeid(nodecnt));
                 if ~isempty(indy)
                     %%% current triangle uses current node!
                     triids=[triids layer.tri(tricnt).id];
                 end; % if ~isempty(indy)
            case {'triangle','empty'}
            otherwise
                error(['MKLSGRIDGETTRIANGLE: unknown triangle child type '...
               upper(layer.tri(trinr).childtype)]);
        end; % sitch
    end; % for nodecnt
end; % for tricnt

%%% make list unique
triids=unique(triids);

%%% and we're done
%return;