function evalthese=mklsgridnonready(lsopt,mygrid,cumdatacnt);
% mklsgridnonready.......return IDs of node that require further evaluation
%
% call: evalthese=mklsgridnonready(lsopt,mygrid,cumdatacnt);
%
%       lsopt: (structure)
%              LOCSMITH options struture as returned by MKLSOPT
%
%       mygrid: (structure)
%              LOCSMITh search grid as returned by MKLSGRIDNEW
%
%       cumdatacnt: (number)
%              The IDs of all nodes of MYGRID that were evaluated for less
%              or equal CUMDATACNT data values.
%
%
% result: evalthese: (structure)
%                    structure denoting the nodes that need further
%                    evaluation. The fields of this structure depend on the
%                    type of the used search grid, as defined by
%                    MYGRID.TYPE:
%
%                    mygrid.type=='triangular': EVALTHESE has the following
%                    fields:
%                      A struture variable that defines the layers and
%                      nodes to be tested. The following fields are
%                      contained:
%                      .layer: (numeric)
%                              layer ID, only one per element of EVALTHESE
%                      .nodes: (numeric array)
%                              list of nodes. This is a sublist of the
%                              nodes list in the mygrid.layer field,
%                              contining node IDs and coordinates formatted
%                              as in the layer structure.
%                      .listpos: (numeric array)
%                              list of positions of the nodes in the
%                              original .nodes field of the input layer.
%                              evalthese.listpos(i) is the array indes of
%                              the node evalthese.nodes(i,:) wihtin the
%                              original layer structure.
%
%                      evalthese(i).layer defines a layer in which
%                      evaluations of shall be made. Then
%                      evalthese(i).nodes is a list of node IDs that
%                      defines which nodes of the specifed layer are to
%                      be evaluated.
%                      If n layers are to be evaluated, EVALTHESE must consist
%                      of n elements, each having its own .layer and
%                      .nodes fields.
%
%                    mygrid.type=='cartesian': not yet supported.
%                   
% Martin Knapmeyer, 10.02.2005



%%% handle different grid types
switch mygrid.type
    case {'triangular'}
        %%% init result
        layeranz=length(mygrid.layers); % number of layers in grid
        evalthese=repmat(struct('layer',[],'nodes',[]),1,layeranz);

        %%% identify nodes to be evaluated
        for layerindy=1:layeranz
            indies=find(mygrid.layers(layerindy).tested(:,2)<=cumdatacnt);
            evalthese(layerindy).layer=mygrid.layers(layerindy).id;
            evalthese(layerindy).nodes=mygrid.layers(layerindy).nodes(indies,:);
            evalthese(layerindy).listpos=indies;
        end; % for layerindy
    case {'cartesian'}
        mklsnotyet('crash');
    otherwise
        error(['MKLSGRIDNONREADY: unknown grid type ' upper(mygrid.type)]);
end; % switch mygrid.type


