function overlaps=mklsgridoverlapccrtri(layer,trinr,trilist);
% mklsgridoverlapccrtri...find triangles with overlapping circumcircles
%
% call: overlaps=mklsgridoverlapccrtri(layer,trinr,trilist);
%
%                  layer: (struct)
%                         FXS layer structure as returned by
%                         MKLSGRIDFXSLAYERTRI
%                  trinr: (number)
%                         index of a triangle within the triangle list of
%                         LAYER
%                trilist: (numeric array)
%                         List of triangle IDs: the triangles with these
%                         IDs in the LAYER will be tested for being
%                         neighbours of the triangle identified by TRINR
%
% result: overlaps: (numeric array)
%                   List of triangle IDs: The circumcircles of these
%                   triangles overlap with the circumcircle of the triangle
%                   at position TRINR in the layers triangle list.
%
% Circumcircles of two triangles are considered to overlap if the distance 
% between the circumcenters is equal or less than the sum of the radii of
% the two circumcircles. (the radii sum will be equal to the circumcenter
% distance if the two triangles have just a common node).
%
% Martin Knapmeyer, 03.12.2004
%                   recursive tree search 07.12.2004


%%% init result
overlaps=[];

%%% how many triangles to test?
trianz=length(trilist);


indexlist=mklsgridgettriangletri(layer,trilist);

%%% loop over triangle list
for indy=1:trianz
        
        
        %%% determine index of triangle with current ID
        currentindex=indexlist(indy); %mklsgridgettriangletri(layer,trilist(indy));

        %%% Does the circumcircle of this triangle overlap with the
        %%% circumcircle of the triangle indentified by TRINR?
        %%% If yes: recursive action might be necessary
        %%% If no: forget this triangle, do nothing.
        
        
        %%% plot triangles that are currently compared
        %%% (only for debugging purposes, since it wastes much time!)
        %mklsgridplottriangle(layer,[layer.tri(trinr).id, trilist(indy)]);

        %%% compute circumcenter distance
        ccdist=mklsepidist(layer.tri(trinr).cc(1),layer.tri(trinr).cc(2),...
                           layer.tri(currentindex).cc(1),layer.tri(currentindex).cc(2));
        %%% compute sum of circumcircle radii
        thresh=layer.tri(trinr).cr+layer.tri(currentindex).cr;
        %%% compare circumcircle radius with circumcenter distance
        if ccdist<=thresh

            %%% triangles overlap.
            %%% If the triangle has triangles as children, test these recursively.
            %%% If the triangles has nodes as children, add its ID to the list
            %%% of tringles to be iterated.
            %%% in all other cases, crash.
            switch layer.tri(currentindex).childtype %childtype
                case {'node'}
                    overlaps=[overlaps layer.tri(currentindex).id];
                case {'triangle'}
                    recursion=mklsgridoverlapccrtri(layer,trinr,layer.tri(currentindex).child);
                    overlaps=[overlaps recursion];
                case {'empty'}
                    error(['MKLSGRIDOVERLAPCCTRI: triangles should not be empty here!']);
                otherwise
                    error(['MKLSGRIDOVERLAPCCTRI: unknown child type ' upper(childtype)]);
            end; % switch childtype

        end; % if ccdist<=thresh
        
    
end; % for indy


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% HERE COMES THE OLD, LINEAR VERSION. THIS VERSION WORKS, BUT IS A BIT TOO
%% SLOW. MK07.12.2004
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 
% %%% init result
% overlaps=[];
% 
% %%% how many triangles?
% trianz=length(layer.tri);
% 
% 
% %%% loop over triangle list and compare
% for indy=1:trianz
%     
%     %%% compare only with triangles that have nodes as children
%     %childtype=(layer.tri(indy).childtype);
%     switch layer.tri(indy).childtype %childtype
%         case {'node'}
%             %%% compute circumcenter distance
%             ccdist=mklsepidist(layer.tri(trinr).cc(1),layer.tri(trinr).cc(2),...
%                                layer.tri(indy).cc(1),layer.tri(indy).cc(2));
%             %%% compute sum of circumcircle radii
%             thresh=layer.tri(trinr).cr+layer.tri(indy).cr;
%             %%% compare
%             if ccdist<=thresh
%                 %%% circumcircles of triangles TRINR and INDY overlap
%                 %%% --> append to output list
%                 overlaps=[overlaps layer.tri(indy).id];
%             else
%                 %%% circumcircles do not overlap --> do nothing.
%             end; % if ccdist<=thresh
%         case {'triangle'}
%             %%% nothing happens
%             %%% in fact, one could build a recursive search algorithm, that
%             %%% tests if the TRINR triangle overlaps with parent triangles
%             %%% - if not, you do not need to waste time with the daughter
%             %%% triangles.
%             %%% May be in a later version.
%         case {'empty'}
%             error(['MKLSGRIDOVERLAPCCTRI: triangles should not be empty here!']);
%         otherwise
%             error(['MKLSGRIDOVERLAPCCTRI: unknown child type ' upper(childtype)]);
%     end; % switch childtype
% end; % for indy
% 
% 
% %disp(['MKLSGRIDOVERLAPCCTRI: overlaps found:' int2str(length(overlaps))]);
% 
% 
% %%% and we're done