function mklsgridplottriangle(layer,id);
% mklsgridplottriangle......plot a single triangle from a layer
%
% call:  mklsgridplottriangle(layer,id);
%
%        layer: a complete LAYER structure as returned by
%                    MKLSGRIDNEWTRILAYER
%           id: list of IDs of triangles in the LAYER
%
% result: none.
%
% Plots single triangles of the layer, identified by their ID.
% If the triangle has no nodes as children, nothing happens.
%
% Martin Knapmeyer, 07.12.2004


figure(1);

%%% a useful constant
radian=pi/180;

%%% how many triangles
trianz=length(id);


%%% loop over triangle list
for indy=1:trianz
    
    %%% get triangle index
    triindex=mklsgridgettriangletri(layer,id(indy));
    
    
    if ~isempty(layer.tri(triindex).nodes)
    
        %%% get nodes
        [rownum,node1]=mklsgridgetnodetri(layer.tri(triindex).nodes(1),layer);
        [rownum,node2]=mklsgridgetnodetri(layer.tri(triindex).nodes(2),layer);
        [rownum,node3]=mklsgridgetnodetri(layer.tri(triindex).nodes(3),layer);

        %%% from radian to degree
        node1=node1*radian;
        node2=node2*radian;
        node3=node3*radian;

        %%% from spherical to cartesian
        [nx(1),ny(1),nz(1)]=sph2cart(node1(2),node1(3),1);
        [nx(2),ny(2),nz(2)]=sph2cart(node2(2),node2(3),1);
        [nx(3),ny(3),nz(3)]=sph2cart(node3(2),node3(3),1);

        %%% plot triangle
        hold on
        patch(nx,ny,nz,[0.8 0.8 1]);
        hold off
    
    end; % if ~isempty(layer.tri(triindex).nodes)
    
end; % for indy