function times=mklsgridtimeslist(idlist);
% mklsgridtimeslist......create new origin times list struct
%
% call: times=mklsgridtimeslist(idlist);
%
%    idlist: (numeric array)
%            list of node IDs for which a times struct is to be constructed
%
% result: times: (struct array)
%                     This field specifies the origin time intervals in
%                     which the maximum quality measure for each node is
%                     reached. It is a sub-structure with the following
%                     fields:
%                     .id: (number)
%                          Node ID, the ID of the node for which the
%                          entries are valid origin times.
%                     .starts: (numeric array) [sec]
%                              start times of origin time intervals
%                     .ends: (numeric array) [sec]
%                            end times of origin time intervals.
%                     The j-th acceptable origin time interval starts at
%                     .times(i).starts(j) and ends at .times(i).ends(j).
%                     Upon initialization, the starts and ends fields are
%                     empty.
%
% Martin Knapmeyer, 22.02.2005

%%% how many nodes?
nodeanz=length(idlist);

%%% create empty struct
times=repmat(struct('id',0,'starts',[],'ends',[]),nodeanz,1);

%%% cpoy IDs intostruct
for indy=1:nodeanz
    times(indy).id=idlist(indy);    
end; % for indy