function edgelens=mklsgridtriedgelen(lonlist,latlist,r);
% mklsgridtriedgelen......determine edge lengths of a spherical triangle
%
% call: edgelens=mklsgridtriedgelen(lonlist,latlist,r);
%
%                 lonlist: longitudes of triangle corners [deg]
%                 latlist: latitudes of triangle corners [deg]
%
%                          lonlist(i),latlist(i) gives the position of the
%                          i-th corner of the triangle.
%
%                       r: sphere radius [km]
%
% result: edglelens: vector containing the edge lengths of the triangle
%                    in km.
%                    edgelens(1) is the length from 1st to 2nd corner
%                    edgelens(2) is the length from 2nd to 3rd corner
%                    edgelens(3) is the length from 3rd to 1st corner
%
% Martin Knapmeyer, 14.09.2004

%%% init result
edgelens=[0 0 0];

%%% 1st to 2nd corner
c1=1;
c2=2;
dist=mklsepidist(latlist(c1),lonlist(c1),latlist(c2),lonlist(c2));
edgelens(c1)=dist;

%%% 2nd to 3rd corner
c1=2;
c2=3;
dist=mklsepidist(latlist(c1),lonlist(c1),latlist(c2),lonlist(c2));
edgelens(c1)=dist;

%%% 3rd to 1st corner
c1=3;
c2=1;
dist=mklsepidist(latlist(c1),lonlist(c1),latlist(c2),lonlist(c2));
edgelens(c1)=dist;


%%% from degrees to km
kmperdegree=2*pi*r/360;
edgelens=edgelens*kmperdegree;