function trilist=mklsgridtrinodeid2row(layer);
% mklsgridtrinodeid2row.......convert node ID list into array row indices
%
% call: trilist=mklsgridtrinodeid2row(layer);
%
%       layer: (struct)
%              layer structure as returned by MKLSGRIDNEWTRILAYER
%
% result: trilist: triangle list with entries pointing to array rows
%                  of the .nodes field of LAYERS.
%                  This triangle list is analoguous to that needed e.g. by
%                  trimesh(). Use this list to plot the triangles via
%                  trimesh or trisurf.
%
% Martin Knapmeyer, 13.09.2004

%%% init result
trilist=zeros(length(layer.tri),3)+NaN; %[];

%%% transform the node-ID based triangle list into a list that
%%% refers to array rows
%%% first step: collect all node references into an array
trianz=length(layer.tri); % number of triangles in layer
for indy=1:trianz
    
    if strcmp(layer.tri(indy).childtype(1),'n')
        trilist(indy,:)=layer.tri(indy).nodes; 
    end; % if strcmp(layer.tri(indy).childtype(1),'n')
    
    %     %childtype=layer.tri(indy).childtype;
    %     switch layer.tri(indy).childtype %childtype
    %         case {'node'}
    %             trilist(indy,:)=layer.tri(indy).nodes; %trilist=[trilist; layer.tri(indy).nodes];
    %         case {'triangle'}
    %             %%% nothing happens with triangles
    %         case {'empty'}
    %             %%% there shouldn't be any empty triangles!
    %             error(['MKLSGRIDTRINODEID2ROW: triangle #',...
    %                    int2str(indy),...
    %                    ' has no children!'] );
    %         otherwise
    %             error(['MKLSGRIDTRINODEID2ROW: unknown child type ',...
    %                    upper(childtype)]);
    %     end; % switch childtype

end; % for indy
%%% TRILIST now contains a triangle list made up of node IDs

%%% remove all lines that contain NaNs
%%% such lines appear when layer.tri(indy).nodes is empty
usedlines=find(~isnan(trilist(:,1)));
trilist=trilist(usedlines,:);

%%% second step: transform node IDs into array row numbers
trilistlen=size(trilist,1); % numbe of triangles having node-children
xyzid=layer.nodes(:,1);
for indy=1:trilistlen
    for j=1:3
        rownumber=find(trilist(indy,j)==xyzid);
        if isempty(rownumber)
            error('MKLSGRIDTRINODEID2ROW: non-existing ID found!');
        else
            trilist(indy,j)=rownumber;
        end; % if isempty(rowumber)
    end; % for j
end; % for indy

%%% return result
% trilist is already in its output variable