function newidlist=mklsgriduniqidlist(idlist);
% mklsgriduniqidlist........make idlist entries unique
%
% call: newidlist=mklsgriduniqidlist(idlist);
%
%       idlist: (structure array)
%               an idlist-strucutre as needed by MKLSGRIDMODIFY
%
%               For triangular grids:
%
%                     The following fields are  expected:
%                     .layer: (numeric)
%                             layer ID, only one per element of IDLIST.
%                     .triangle: (numeric array)
%                                list of triangle IDs
%
%                     idlist(i).layer defines a layer in which
%                     modifications on triangles shall be made. Then
%                     idlist(i).triangle is a list of triangle IDs that
%                     defines which triangles of the speicifed layer are to
%                     be modified.
%                     If n layers are to be modified, IDLIST must consist
%                     of n elements, each having its own .layer and
%                     .triangle fields.
%
%               For cartesian grids:
%             
%                     (not yet implemented)
%
% result: newidlist: (structure array)
%                    a modified version of IDLIST, in which all ambiguities
%                    from multiply listed items are removed.
%
%                    For triangular grids:
%
%                    multiple references to the same layer have been
%                    concatenated into a single element. Multiple
%                    references to the same triangle ID have been removed.
%
% Martin Knapmeyer, 24.02.2005


%%% determine grid type for which the IDLISt ist valid
%%% This can be done by looking at the fields: if the grid is triangular,
%%% a field "triangle" exists.
if isfield(idlist(1),'triangle')
    %%% a field named 'triangle' exists => triangular grid!
    gridtype='triangular';
else
    %%% a field named 'triangle' does not exist
    %%% at this place, it must be determined if it is a cartesian grid or
    %%% something illegal!
    error(['MKLSGRIDUNIQIDLIST: unknown type of IDLIST structure!']);
end; % if isfield

%%% dispatch for different grid types
switch gridtype
    case {'triangular'}
        newidlist=mklsgriduniqidlisttri(idlist);
    case {'cartesian'}
        mklsnotyet('crash');
    otherwise
        error(['MKLSGRIDUNIQIDLIST: unknown grid type' upper(gridtype)]);
end; % switch
