function [midlon,midlat]=mkmidpoint(lon1,lat1,lon2,lat2);
% mkmidpoint........compute middle of great circle arc between two points
%
% call: [midlon,midlat]=mkmidpoint(lon1,lat1,lon2,lat2);
%
%                       lon1: (number) [deg]
%                             longitude of 1st point
%                       lat1: (number) [deg]
%                             latitude of 1st point
%                       lon2: (number) [deg]
%                             longitude of 2nd point
%                       lat2: (number) [deg]
%                             latitude of 2nd point
%
% result: midlon: (number) [deg]
%                 longitude of the point in the middle
%         midlat: (number) [deg]
%                 latitude of the point in the middle
%
% The mid-point computation is needed for the refinement of triangular
% grids, where the edges of triangles are divided in the middle to form the
% edges of new, smaller triangles.
% The computation is a quite simple vector addition procedure.
%
% Martin Knapmeyer, 15.09.2004

%%% a useful constant, once again
radian=pi/180;

%%% from spherical to cartesian
[p1(1),p1(2),p1(3)]=sph2cart(lon1*radian,lat1*radian,1);
[p2(1),p2(2),p2(3)]=sph2cart(lon2*radian,lat2*radian,1);

%%% midpoint computation
mid=(p1+p2)/2;

% hold on
% plot3(p1(1),p1(2),p1(3),'.');
% plot3(p2(1),p2(2),p2(3),'.');
% plot3(mid(1),mid(2),mid(3),'.');
% hold off

%%% from cartesian to spherical
[midlon,midlat]=cart2sph(mid(1),mid(2),mid(3));

%%% from arc to degrees
midlon=midlon/radian;
midlat=midlat/radian;

%%% normalize to values in 0...360 for longitude and
%%% -90...90 for latitude
if midlon<0
   midlon=midlon+360;
end;