function lsd=mklsemptylsd(statcnt,eventcnt,arrivalcnt);
% mklsemptylsd........construct empty LSD structure of given size
%
% call: lsd=mklsemptylsd(statcnt,eventcnt,arrivalcnt);
%
%           statcnt: (number) [counter]
%                    number of stations to be stroed in LSD
%           eventcnt: (nuymber) [counter]
%                    number of events to be stored in LSD
%           arrivalcnt: (number) [counter]
%                    number of arrivals to be described in LSD
%
% result: LSD: (structure)
%
%              Locsmith Seismic Data structure
%              This structure has the following fields:
%  
%               .statcnt: number of stations defined in structure
%               .eventcnt: number of events defined in structure
%               .arrivalcnt: number of arrival data records defined in structure
%  
%               .station: an array of sub structures containing positions of all stations.
%                         each element of the array has the following fields:
%                         .id: a string containing the station id
%                         .lon: three elements vector defining station longitude
%                         .lat: threee elements vector defining station latitude
%                         .elev: three elements vector defining station elevation
%  
%               .event: an array of sub structures containing informations about all events
%                       each element of the array has the following fields:
%                       .id: a string containing the event ID
%                       .info: a string containing informal additional info
%                       .lon: three elements vector defining constraints for event longitude
%                             (event location is constrainded to this range by external evidence)
%                       .lat: three elements vector defining constraints for event latitude
%                             (event location is constrainded to this range by external evidence)
%                       .depth: three elements vector defining constraints for event focal depth
%                             (event location is constrainded to this range by external evidence,
%                              this is of special importance for meteoroid impacts!)
%                       .ot: three elements vector defining constraints for event focal depth
%                             (event location is constrainded to this range
%                             by external evidence)
%  
%              .arrival: an array of arrival data (which does not imply a source localization)
%                    each element is a sub structure with the following fields:
%                    .id: string containing data record ID
%                    .station: string, containing station identifier
%                    .event: string, containing event identifier
%                    .phase: string, containing seismic phase name
%                    .at: arrival time
%                    .baz: back azimuth angle
%                    .emerg: emergence angle
%                    .slo: slowness
%
% This routine constructs an empty structure like those returned by
% MKREADLSD.
% The structure design as defined in MKREADLSD is the official one, the
% description here is repeated only for you convenience.
%
% MKREADLSD DOES NOT USE THIS ROUTINE!
%
% Martin Knapmeyer, 17.03.2005


lsd=struct('statcnt',statcnt,...
           'eventcnt',eventcnt,...
           'arrivalcnt',arrivalcnt,...
           'station',repmat(struct('id','',...
                                   'lon',[NaN],...
                                   'lat',[NaN],...
                                   'elev',[NaN]),statcnt,1 ...
                            ),...
           'event',repmat(struct('id','',...
                                 'info','',...
                                 'lon',[NaN],...
                                 'lat',[NaN],...
                                 'depth',[NaN],...
                                 'ot',[NaN]),eventcnt,1 ...
                          ),...
           'arrival',repmat(struct('id','',...
                                   'station','',...
                                   'event','',...
                                   'phase','',...
                                   'at',[NaN NaN NaN],...
                                   'baz',[NaN NaN NaN],...
                                   'emerg',[NaN NaN NaN],...
                                   'slo',[NaN NaN NaN]),arrivalcnt,1 ...
                             )...
            );
