function formatted=mklsnumparmsformat(keyword,modifier,unformt,stringparm);
% mklsnumparmsformat........format numeric parameter vector into min-mean-max list
%
% call: formatted=mklsnumparmsformat(keyword,modifier,unformt,stringparm);
%
%       keyword: the keyword from the lsd file
%       modifier: the modifier from the lsd file
%       unformt: unformatted parameter list
%                This is the numeric parameter list extracted from lsd file
%       stringparms: the stringparameters found for the current line
%
% result: formatted: formatted numeric parameter list
%                    in most cases, this will be a 3 elements vector with
%                    formatted(1): lower boundary
%                    formatted(2): "likely to be true" value or NaN if not specified in file
%                    formatted(3): upper boundary
%
%                    in some cases, depending on keyword and modifier, this will
%                    be a single value, the true value. (example: the planets radius
%                    is usually known so precise that giving boundaries is not neccessary.)
%
%                    In case of a non-empty STRINGPARM, FORMATTED will be empty.
%
% Since parameters aer either numeric _or_ string in LSD files, a non-empty STRINGPARM
% means that there is no numeric parameter to be formatted. Or vice versa, if the string
% parameter is not empty, the formatting will be applied to the numeric parameter.
%
% Martin Knapmeyer, 09.09.2003


% !!!!
% The file format has been renamed from SID to LSD by MK, 03.02.2005
% But i didn't change the internal variable names to avoid the introduction
% of bugs. Only the variable names in the held lines have been changed!

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                                                                    %%
%% the following routine is format-specific: keywords and modifiers and their         %%
%% properties are hardwired here. future versions may use a description file, I hope. %%
%%                                                                                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% init result
formatted=[NaN NaN NaN];

if (isempty(stringparm))&(strcmp(modifier,'end')==0)

   %%% format
   if (strcmp(keyword,'station'))&...
        ((strcmp(modifier,'lon'))|(strcmp(modifier,'lat'))|(strcmp(modifier,'elev')))
      %%% 1 element output
      panz=length(unformt);
      switch panz
         case {1}
             formatted=unformt;
         otherwise
             error(['MKLSNUMPARMSFORMAT: illegal number of parameters for ',...
                    keyword '/' modifier '!']);
      end; % switch panz
   else
      %%% 3 element output
      panz=length(unformt);
      switch panz
          case {2}
               formatted(1)=min(unformt);
               formatted(3)=max(unformt);
          case {3}
               indies=find(isnan(unformt));
               switch length(indies)
                  case {0}
                     formatted=sort(unformt);
                  case {1}
                     formatted(1)=min(unformt);
                     formatted(2)=NaN;
                     formatted(3)=max(unformt);
                  otherwise
                     error('MKLSNUMPARMSFORMAT only one NaN allowed in numeric parameters!');
               end; % swith length(indies)
               
               
          otherwise
              error(['MKLSNUMPARMSFORMAT: illegal number of parameters for ',...
                      keyword '/' modifier '!']);
      end; % swtich panz
   end; % if else
   
else

   formatted=[];

end; % if isempty(stringparm)

return;