function [newlsd]=mklsparm2lsd(oldsid,keyword,modifier,numparms,stringparms);
% mklsparm2sid.........builds sid structure field from identified keywords & parameters
%
% call: [newlsd]=mklsparm2lsd(oldlsd,keyword,modifier,numparms,stringparms);
%
%       oldlsd: existing sid structure
%       keyword: keyword identified by MKLSSPLITTOKENLIST
%       modifer: modifier identified by MKLSSPLITTOKENLIST
%       numparms: numeric paramater list returned by MKLSPARMCONSOLID
%       stringparms: string parameter returned by MKLSPARMCONSOLID
%
% result: newlsd: new LSD structure with additional fields as defined by input.
%
% For definition of the LSD structure see help lines of MKLSREADLSD.
%
%
% Martin Knapmeyer 03.09.2003, 09.09.2003

% !!!!
% The file format has been renamed from SID to LSD by MK, 03.02.2005
% But i didn't change all internal variable names to avoid the introduction
% of bugs. Only the variable names in the held lines have been changed!


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                                                                    %%
%% the following routine is format-specific: keywords and modifiers and their         %%
%% properties are hardwired here. future versions may use a description file, I hope. %%
%%                                                                                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% MKPARMCONSOLID has already checked syntax. Here we can assume aeverything is OK!
% we assume that
% - KEYWORD and MODIFIER are lowercase
% - NUMPARMS and STRINGPARMS are not empty when numeric or string parms are required

%%% init output
newlsd=oldsid;

%%% init empty dummy station, event, tt, arrival structures
newstation.id=[];
newstation.lon=[1 1 1]*NaN;
newstation.lat=[1 1 1]*NaN;
newstation.elev=[1 1 1]*NaN;

newevent.id=[];
newevent.info=[];
newevent.lon=[1 1 1]*NaN;
newevent.lat=[1 1 1]*NaN;
newevent.depth=[1 1 1]*NaN;
newevent.ot=[1 1 1]*NaN;

newtt.id=[];
newtt.station=[];
newtt.event=[];
newtt.phase=[];
newtt.dist=[1 1 1]*NaN;
newtt.tt=[1 1 1]*NaN;
newtt.depth=[1 1 1]*NaN;

newarrival.id=[];
newarrival.station=[];
newarrival.event=[];
newarrival.phase=[];
newarrival.at=[1 1 1]*NaN;
newarrival.baz=[1 1 1]*NaN;
newarrival.emerg=[1 1 1]*NaN;
newarrival.slo=[1 1 1]*NaN;

%%% dispatch input
if ~isempty(keyword)

   %%% dispatch input to respective fields
   switch keyword
%        case {'universal'}
%             switch modifier
%                 case {'newton'}
%                      newlsd.newton=numparms;
%                 otherwise
%                      error(['MKLSPARM2SID: keyword ' upper(keyword) ' with illegal modifier ' upper(modifier)]);
%             end; % switch modifier
%        case {'planet'}
%             switch modifier
%                 case {'name'}
%                      newlsd.planet.name=stringparms;
%                 case {'radius'}
%                      newlsd.planet.radius=numparms;
%                 case {'gm'}
%                      newlsd.planet.gm=numparms;
%                 case {'mif'}
%                      newlsd.planet.mif=numparms;
%                 otherwise
%                      error(['MKLSPARM2SID: keyword ' upper(keyword) ' with illegal modifier ' upper(modifier)]);
%             end; % switch modifier
       case {'station'}
            switch modifier
                case {'start'}
                    newlsd.station=[newlsd.station newstation];
                    newlsd.statcnt=newlsd.statcnt+1;
                    newlsd.station(newlsd.statcnt).id=stringparms;
                case {'lon'}
                    newlsd.station(newlsd.statcnt).lon=numparms;
                case {'lat'}
                    newlsd.station(newlsd.statcnt).lat=numparms;
                case {'elev'}
                    newlsd.station(newlsd.statcnt).elev=numparms;
                case {'end'}
                    %%% nothing happens
                otherwise
                     error(['MKLSPARM2SID: keyword ' upper(keyword) ' with illegal modifier ' upper(modifier)]);
            end; % switch modifier
            
       case {'event'}
            switch modifier
               case {'start'}
                    newlsd.event=[newlsd.event newevent];
                    newlsd.eventcnt=newlsd.eventcnt+1;
                    newlsd.event(newlsd.eventcnt).id=stringparms;
               case {'info'}
                    newlsd.event(newlsd.eventcnt).info=stringparms;
               case {'lon'}
                    newlsd.event(newlsd.eventcnt).lon=numparms;
               case {'lat'}
                    newlsd.event(newlsd.eventcnt).lat=numparms;
               case {'depth'}
                    newlsd.event(newlsd.eventcnt).depth=numparms;
               case {'ot'}
                    newlsd.event(newlsd.eventcnt).ot=numparms;
               case {'end'}
                    %%% nothing happens
               otherwise
                     error(['MKLSPARM2SID: keyword ' upper(keyword) ' with illegal modifier ' upper(modifier)]);
            end; % switch modifier
       
%        case {'tt'}
%             switch modifier
%                case {'start'}
%                     newlsd.tt=[newlsd.tt newtt];
%                     newlsd.ttcnt=newlsd.ttcnt+1;
%                     newlsd.tt(newlsd.ttcnt).id=stringparms;
%                case {'station'}
%                     newlsd.tt(newlsd.ttcnt).station=stringparms;
%                case {'event'}
%                     newlsd.tt(newlsd.ttcnt).event=stringparms;
%                case {'phase'}
%                     newlsd.tt(newlsd.ttcnt).phase=stringparms;
%                case {'dist'}
%                     newlsd.tt(newlsd.ttcnt).dist=numparms;
%                case {'tt'}
%                     newlsd.tt(newlsd.ttcnt).tt=numparms;
%                case {'depth'}
%                     newlsd.tt(newlsd.ttcnt).depth=numparms;
%                case {'end'}
%                     %%% nothing happens
%                otherwise
%                     error(['MKLSPARM2SID: keyword ' upper(keyword) ' with illegal modifier ' upper(modifier)]);
%             end; % switch modifier
       
       case {'arrival'}
           switch modifier
               case {'start'}
                    newlsd.arrival=[newlsd.arrival newarrival];
                    newlsd.arrivalcnt=newlsd.arrivalcnt+1;
                    newlsd.arrival(newlsd.arrivalcnt).id=stringparms;
               case {'station'}
                    newlsd.arrival(newlsd.arrivalcnt).station=stringparms;
               case {'event'}
                    newlsd.arrival(newlsd.arrivalcnt).event=stringparms;
               case {'phase'}
                    newlsd.arrival(newlsd.arrivalcnt).phase=stringparms;
               case {'at'}
                    newlsd.arrival(newlsd.arrivalcnt).at=numparms;
               case {'baz'}
                    newlsd.arrival(newlsd.arrivalcnt).baz=numparms;
               case {'emerg'}
                    newlsd.arrival(newlsd.arrivalcnt).emerg=numparms;
               case {'slo'}
                    newlsd.arrival(newlsd.arrivalcnt).slo=numparms;
               case {'end'}
                    %%% nothing happens
               otherwise
                    error(['MKLSPARM2SID: keyword ' upper(keyword) ' with illegal modifier ' upper(modifier)]);
            end; % switch modifier
       
       otherwise
           error(['MKLSPARM2SID: unknown keyword ' upper(keyword)]);
   end; % switch keyword

end; % if ~isempty

return;