function mklsplotlsd(lsdin,plotwhat);
% mkplotlsd.......plot data from SID stricture
%
% call: mklsplotlsd(lsdin,plotwhat);
%
%       lsdin: LOCSMITH LSD structure as returned by MKLSREADLSD
%       plotwhat: string which defines what to plot
%                 available are:
%                 'stations'
%                 not case sensitive
%
% result: none
%
% This routine is intended to provide quick overviews of the content of an
% LSD structure, not to produce sophisticated publication-ready figures.
%
% Martin Knapmeyer, 22.09.2003, 03.02.2005


% !!!!
% The file format has been renamed from SID to LSD by MK, 03.02.2005
% But i didn't change the internal variable names to avoid the introduction
% of bugs. Only the variable names in the held lines have been changed!


%%% define some colors
stationcolor=mklsconstants('NodeColor');


%%% switch
plotwhat=lower(plotwhat);
switch plotwhat

    case {'stations'}
        clf;
        lon=[];
        lat=[];
        stationnames=[];
        for indy=1:lsdin.statcnt
            lon=[lon lsdin.station(indy).lon];
            lat=[lat lsdin.station(indy).lat];
            stationnames=strvcat(stationnames,['  ' lsdin.station(indy).id]);
        end; % for indy
        hold on
           h=plot(lon,lat,'^');
           set(h,'MarkerFaceColor',stationcolor);
           set(h,'MarkerEdgeColor',stationcolor);
           text(lon,lat,stationnames);
        hold off
        
        axis equal
        axis([-180 180 -90 90]);
        box on
        grid on
        title('Station Network');
        xlabel('Longitude');
        ylabel('Latitude');
        
   otherwise
      error(['MKLSPLOTSID: unknown option ' upper(plotwhat)]);
end; % switch plotwhat