function [keyword,modifier,parmlist]=mklssplittokenlist(tokenlist,linecnt,silent);
% mklssplittokenlist.........divide token list into keyword, modifier, and parameter list
%
% call: [keyword,modifier,parmlist]=mklssplittokenlist(tokenlist,linecnt,silent);
%
%       tokenlist: string matrix containing token list, as returned by MKSPLITLINE
%       linecnt: line counter, needed in error messages
%       silent: verbosity flag:
%               1: run silent
%               0: run verbose
%
% result: keyword: string containing the keyword (without "!")
%                   empty if no keyword present
%         modifier: string containing the modifier to the keyword (without "!"),
%                   empty if no modifier present
%         parmlist: string matrix, containing all parameters
%                   empty if no parameters present
%
% Keywords and Modifiers are recognized by 
% a) position in TOKENLIST and
% b) preceeding exclamation mark
%
% Martin Knapmeyer, 01.09.2003


%%% init output
keyword=[];
modifier=[];
parmlist=[];

tokcnt=size(tokenlist,1);
if tokcnt==0
   %%% token list is empty
else
   %%% token list is not empty
   keyword=deblank(tokenlist(1,:));
   if strcmp(keyword(1),'!')~=1
      error(['MKLSSPLITTOKENLIST: Exclamation mark missing at begin of line '...
             int2str(linecnt) ' of file.']);
   else
      keyword=keyword(2:end); % strip off exclamation mark
      if tokcnt>1
         %%% other tokens might be modifier and parameters
         modifier=deblank(tokenlist(2,:));
         if strcmp(modifier(1),'!')~=1
            %%% not identified as modifier ("!" missing)
            modifier=[];
            parmlist=tokenlist(2:tokcnt,:);
         else
            modifier=modifier(2:end); % strip off exclamation mark
            if tokcnt>2
               %%% remaining tokens are parameters
               parmlist=tokenlist(3:tokcnt,:);
            end; % if tokcnt>2
         end; % strcmp(modifier(1),'!')~=1 else
      else
         %%% no more tokens
         modifier=[];
         parmlist=[];
      end; % if tokcnt>1 else
   end; % if strcmp((keyword(1),'!')~=1
end; % if tokcnt

%%% tell them what we've found
if ~silent
   if ~isempty(keyword)
      disp(['MKLSSPLITTOKENLIST: keyword ' upper(keyword) ' identified.']);
   end; % if ~isempty(keyword)
   if ~isempty(modifier)
      disp(['MKLSSPLITTOKENLIST: modifier ' upper(modifier) ' identified.']);
   end; % if ~isempty(modifier)
end; % if ~silent

%%% if parmlist is empty, make an error
if (tokcnt>0)&(isempty(parmlist))&(strcmp(modifier,'end')==0)
   error(['MKLSSPLITTOKENLIST: line ' int2str(linecnt),...
          ': illegally empty parameter list for modifier ' upper(modifier) '!']);
end; % if isempty(parmlist)


%%% case insensitive output of keywords and modifiers
keyword=lower(keyword);
modifier=lower(modifier);

return;