function mklswritelsd(sidin,pfad);
% mklswritelsd.........write LSD structure to .lsd file
%
% call: mklswritelsd(lsdin,pfad);
%
%       lsdin: LSD structure to be written to file
%              for definition of this structure see MKLSREADLSD.
%
%       pfad: complete path and file name to store file.
%
% result: none
%
% Martin Knapmeyer, 10.09.2003, adapted for LOCSMITH 02.02.2005


% !!!!
% The file format has been renamed from SID to LSD by MK, 03.02.2005
% But i didn't change the internal variable names to avoid the introduction
% of bugs. Only the variable names in the held lines have been changed!

%%% open file
[fid,msg]=fopen(pfad,'w+');
if fid==-1
   error(['MKLSWRITELSD: ' msg]);
end; % if fid==-1

%%% write some heading comment
fprintf(fid,'// LSD file generated by MKLSWRITELSD %s\n',date);
fprintf(fid,'// LOCSMITH package (c) Martin Knapmeyer 2004-...\n');
fprintf(fid,'//\n');
fprintf(fid,'\n'); % empty line



%%% write station information
if sidin.statcnt~=0
   fprintf(fid,'// Station Information\n');
   fprintf(fid,'\n'); % empty line
   for indy=1:sidin.statcnt
       fprintf(fid,'!station !start %s\n',sidin.station(indy).id);
    
       line=mklsvector2line('station','lon',sidin.station(indy).lon);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('station','lat',sidin.station(indy).lat);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('station','elev',sidin.station(indy).elev);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       fprintf(fid,'!station !end \n');
       fprintf(fid,'\n'); % empty line
   end; % for indy
end; % if sidin.statcnt

%%% write event information
if sidin.eventcnt~=0
   fprintf(fid,'// Event Information\n');
   fprintf(fid,'\n'); % empty line
   for indy=1:sidin.eventcnt
       fprintf(fid,'!event !start %s\n',sidin.event(indy).id);
       fprintf(fid,'!event !info %s\n',sidin.event(indy).info);
    
       line=mklsvector2line('event','lon',sidin.event(indy).lon);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('event','lat',sidin.event(indy).lat);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('event','depth',sidin.event(indy).depth);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('event','ot',sidin.event(indy).ot);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       fprintf(fid,'!event !end \n');
       fprintf(fid,'\n'); % empty line
   end; % for indy
end; % if

% %%% write travel time information
% if sidin.ttcnt~=0
%    fprintf(fid,'// Travel Time Information\n');
%    fprintf(fid,'\n'); % empty line
%    for indy=1:sidin.ttcnt
%       fprintf(fid,'!tt !start %s\n',sidin.tt(indy).id);
%       fprintf(fid,'!tt !station %s\n',sidin.tt(indy).station);
%       fprintf(fid,'!tt !event %s\n',sidin.tt(indy).event);
%       fprintf(fid,'!tt !phase %s\n',sidin.tt(indy).phase);
%    
%       line=mklsvector2line('tt','dist',sidin.tt(indy).dist);
%       if ~isempty(line)
%          fprintf(fid,'%s\n',line);
%       end; %~isempty(line)
%     
%       line=mklsvector2line('tt','tt',sidin.tt(indy).tt);
%       if ~isempty(line)
%          fprintf(fid,'%s\n',line);
%       end; %~isempty(line) 
%    
%       line=mklsvector2line('tt','depth',sidin.tt(indy).depth);
%       if ~isempty(line)
%          fprintf(fid,'%s\n',line);
%       end; %~isempty(line) 
%    
%       fprintf(fid,'!tt !end \n');
%       fprintf(fid,'\n'); % empty line
%    end; % for indy
% end; % if

%%% write arrival data information
if sidin.arrivalcnt~=0
   fprintf(fid,'// arrival Data Information\n');
   fprintf(fid,'\n'); % empty line
   for indy=1:sidin.arrivalcnt
       fprintf(fid,'!arrival !start %s\n',sidin.arrival(indy).id);
       
       if ~isempty(sidin.arrival(indy).station)
          fprintf(fid,'!arrival !station %s\n',sidin.arrival(indy).station);
       else
           error(['MKLSWRITELSD: Arrival time data must have station identifier!']);
       end; % if ~isempty(sidin.arrival(indy).station)
       
       if ~isempty(sidin.arrival(indy).event)
           fprintf(fid,'!arrival !event %s\n',sidin.arrival(indy).event);
       else
           error(['MKLSWRITELSD: Arrival time data must have event identifier!']);
       end; % if ~isempty(sidin.arrival(indy).station)
       
       if ~isempty(sidin.arrival(indy).phase)
           fprintf(fid,'!arrival !phase %s\n',sidin.arrival(indy).phase);
       else
           error(['MKLSWRITELSD: Arrival time data must have station identifier!']);
       end; % if ~isempty(sidin.arrival(indy).station)
    
       line=mklsvector2line('arrival','at',sidin.arrival(indy).at);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('arrival','baz',sidin.arrival(indy).baz);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('arrival','emerg',sidin.arrival(indy).emerg);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       line=mklsvector2line('arrival','slo',sidin.arrival(indy).slo);
       if ~isempty(line)
          fprintf(fid,'%s\n',line);
       end; %~isempty(line)
    
       fprintf(fid,'!arrival !end \n');
       fprintf(fid,'\n'); % empty line
   end; % for indy
end; % if

%%% write an end-of file notice
fprintf(fid,'\n'); % empty line
fprintf(fid,'// file ends here');


%%% close file
fclose(fid);


return;


% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%                          HELPER ROTUINES                              %%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% function line=mkvector2line(keyword,modifier,vector);
% % mkvector2str.......transforms a coerfficient vector into a output line for clr format
% %
% % call: line=mkvector2line(keyword,modifier,vector);
% %
% %            keyword: sid format keyword string
% %            modifier: sid format modifier string
% %            vector: a 1D vector of numbers
% %
% % result: line: a string which can directly be written to the file
% %                This string contains keyword, modifier, and data
% %               or is empty if data is NaN.
% %
% % Martin Knapmeyer, 03.09.2003
% 
% %%% init output
% line=[];
% 
% %%% add modifier
% line=[line '!' keyword ' !' modifier ' '];
% 
% %%% format vector
% indies=find(isnan(vector));
% switch length(indies)
%    case {0,1}
%       anz=length(vector);
%       for indy=1:anz
%           if isnan(vector(indy))
%              line=[line ' NaN  '];
%           else
%              line=[line sprintf('%1.15f ',vector(indy))];
%           end; % if isnan(vector(indy))
%       end; % for indy
%    case {3}
%       line='';
%    otherwise
%       error(['MKVECTOR2LINE: illegal number of NaNs for ' keyword '/' modifier]);
% end; % stwich length(indies)
% 
% %%% add data vector
% % if ~isnan(vector)
% %    vector=vector(:);
% %    %%% format remaining vector
% %    anz=length(vector);
% %    for indy=1:anz
% %        line=[line sprintf('%1.15f ',vector(indy))];
% %    end; % for indy
% % else
% %    line='';
% % end; % if isnan(vector)