function mkfiatlux(lightstate,varargin);
% mkfiatlux........switch on a single light in the current axes
%
% call: mkfiatlux;
%       mkfiatlux(lightstate);
%       mkfiatlux(lightstate,'PropertyName',PropertyValue,...);
%
%       lightstate: (string)
%                   'on': switch light on
%                   'off': switch all lights off
%                   DEFAULT: 'on'
%
%       PropertyName / PropertyValue pairs denote light object properties
%       and are passed directly to the call of light(), but only when
%       lightstate is set to 'on'. This is meant as a
%       possibility to create a light with specific properties.
%
% result: none
%
% creates a single light object in the current axes. All existing lights
% are deleted before creating the new one.
% This is a simple way to avoid that repeated calls of plot structures
% produce a blinding amount of lights.
%
% Martin Knapmeyer, 26.01.2005, 02.03.2005, 03.03.2005


if nargin==0
    lightstate='on';
end; % if nargin


switch lightstate
    case {'on'}
        mkfiatlux('off'); % deletes all existing lights
        lighthandles=findobj(gca,'type','light');
        if isempty(lighthandles)
            nin=nargin;
            if nin==1
                light;
            else
                light(varargin{:});
            end; % if nin==1
        end; % if isempty(lighthandles)
    case {'off'}
        lighthandles=findobj(gca,'type','light');
        delete(lighthandles);
    otherwise
        error(['MKFIATLUX: unknown light state ' upper(lightstate)]);
end; % switch lightstate