function newoptions=mklscheckopt(options);
% mklscheckopt........check plausibility of LOCSMITH options
%
% call: newoptions=mklscheckopt(options);
%
%       options: options structure as returned by MKLSOPT.
%
% result: newoptions: as OPTIONS, but with minor problems repaired.
%
% This routine checks if the options given in the input contain severe
% nonsense or contradictions and issues errors and warnings to make the user
% aware of any problem.
% IN some cases, the routine repairs problems and just writes a message to
% the screen.
%
% Martin Knapmeyer, 08.09.2004, 25.10.2004, 15.06.2005, 16.09.2005

%%% init result
newoptions=options;

%%% all planet radius values must be identical!
if options.planet_radius~=options.mapopt.planet_radius
    newoptions.mapopt.planet_radius=options.planet_radius;
    disp('MKLSCHECKOPT: planet radius in MAPOPT set to LSOPT value!');
end; % if options.planet_radius~=options.mapopt.planet_radius



%%% at least one evaluation method should be active!
if strcmp(options.eval_baz,'off') &...
   strcmp(options.eval_at,'off') &...
   strcmp(options.eval_dt,'off') &...
   strcmp(options.eval_emerg,'off') &...
   strcmp(options.eval_slo,'off')

   error('MKLSCHECKOPT: at least one data evaluation method should be ON !');
   
end; % if srtcmp(options.eval_baz,'off') &...



%%% the acceptance threshold for extrema, options.iter_matchthresh, must be
%%% between 0 and 100 percent
if options.iter_matchthresh<0
   newoptions.iter_matchthresh=0;
   disp('MKLSCHECKOPT: .iter_matchthresh must be >=0. Set to 0.');
end; % if options.iter_matchthresh<0
if options.iter_matchthresh>100
   newoptions.iter_matchthresh=100;
   disp('MKLSCHECKOPT: .iter_matchthresh must be <=100. Set to 100.');
end; % if options.iter_matchthresh<0



return;