function constant=mklsconstants(constname);
% mklsconstants.........defines some constants used in LOCSMITH
%
% call: constant=mklsconstants(constname);
%
%                constname: string to refer to a specific constant
%                           Not case sensitive.
%                           See below for a list of defined constants and
%                           their 
%                    
%
% result: constant: the constant, corresponding to the
%                   input CONSTNAME. This might be a number, an array
%                   or a string, depending on the constant.
%
% The goal of this routine is to avoid magic numbers that are defined
% somewhere in the code, with nobody knowing how many of them exist and
% where or why they are defined.
%
% The constants defined here are divided into two groups: constants which
% you usually shouldn't change, and constant that are defined here to make
% sure they are available everywhere.
%
%
% You may change he following constants if appropriate for your project:
%
% ReferenceDay: (numeric array) [y m d]
%               times in LOCSMITH are counted in seconds since
%               this day, 00:00:00.
%               Default: [1900 1 1];
%
% Transparency: (number) []
%               The Alpha value used for transparency in several types of
%               grid plots
%
% SphereFacets: (number) []
%               Some plot routines plot additional sphere surfaces as
%               beautification or whatever. This constant is passed into
%               MatLab's sphere() function and thus defines how fine this
%               sphere surface is.
%
% ColorMapLength: (number) [counter]
%               Length of colormaps.
%
% FaceColor:    (number or string) [colspec]
%               Color specification for faces of surfaces that are drawn
%               when plotting grids. This color is used e.g. for th
%               augmenting sphere in "cloud"-plots of gridnodes, but also
%               for the patches in "surface"-plots of grids.
%
% EdgeColor:    (number or string) [colspec]
%               Color specification for faces of surfaces that are drawn
%               when plotting grids. This color is used e.g. for th
%               augmenting sphere in "cloud"-plots of gridnodes, but also
%               for the patches in "surface"-plots of grids.
%
% NodeColor:    (number or string) [colspec]
%               Color specification for points (nodes) that are drawn when 
%               plotting grids.
%               Note that LOCSMITH uses open symbols for inacceptable nodes
%               and filled symbols for acceptable nodes.
%
% NodeMarker:   (string) [linespec]
%                linespec string specifying the marker used by MKLSGRIDPLOT
%                and MKLSGRIDRESPLOT to plot station markers.
%
% StationMarker: (string) [linespec]
%                linespec string specifying the marker used by MKLSNETPLOT
%                to plot station markers.
%
% Lighting: (string)
%               Surface Lighting type used when plotting grids.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% YOU SHOULD BE VERY CAREFUL WHEN CHANGING ONE OF THE FOLLOWING:
%
%
% LocationDemo1: (structure)
%               Default values for the input of MKLSLOCATIONDEMO. These
%               values are used if the location demo routine is called with
%               an incomplete list of arguments or with the "demo1"-call.
%               This case demonstrates location by BAZ only.
%
% LocationDemo2: (structure)
%               Another scenario for MKLSLOCATIONDEMO. These values are
%               used for the "demo2"-call. This is a somewhat pathological
%               case which demonstrates the Attention Creep Effect in a
%               BAZ-only location.
%
% LocationDemo3: (structure)
%               Another scenario for MKLSLOCATIONDEMO. These values are
%               used for the "demo3"-call. This demo demonstrates the evaluation
%               of arrival times. (only P arrival times). Only one depth
%               layer is considered.
%
% LocationDemo4: (structure)
%               Another scenario for MKLSLOCATIONDEMO. These values are
%               used for the "demo4"-call. This demo is a kind of mental
%               preparation for LocationDemo5: in "demo4", a single grid
%               layer is used to determine longitude, latitude and origin
%               time od a deep quake. The layer is at the true depth of
%               that quake.
%
% LocationDemo5: (strcuture)
%                Another scenario for MKLSLOCATIONDEMO. These values are
%                used for the "demo5"-call.
%                The situation here is the same as in "demo4", but in
%                "demo5", LOCSMITH also has to determine the focal depth
%                from arrival times.
%
% LocationDemo6: (strcuture)
%                This is an example of a failure: based on demo4, the
%                configuration used here makes LOCSMITH find a solution
%                with reduced compatibility (2 incompatible data) in an
%                area far away from the true hypocenter.
%                It is important to understand that any method that is
%                based on checking examples may fail, since you cannot
%                prove the nonexistence of alternative solutions by giving
%                examples.
%
% LocationDemo7: (structure)
%                An example for incomplete data and non-uniqueness:
%                The same as demo 5, but with only 2 stations.
%
%
% ReftriRoundoff (number)
%                A large number used to round off the computed edge lengths
%                in MKLSGRIDREFTRI. This roundoff is needed to find the
%                second longest edge in a grid without strugglin over
%                roundoff errors of about 1e-12.
%
% TrianglesTetrahedron  (number)
%                Number of triangles of a Tetrahedron.
%
% TrianglesOctahedron   (number)
%                Number of triangles of an Octahedron.
%
% TrianglesIcosahedron  (number)
%                Number of triangles of an Icosahedron
%
% MaxEdgeTetra:  (numeric array) [deg]
%                List of maximum edge lengths of tetrahedron-based grids.
%                The first element is the edge length of the tetrahedron
%                itself, the second element is the length of the longest
%                edge after one iteration, the third if the same after two
%                iterations and so on.
%                The list given here gives max edge lengths only for a few
%                ietrations. For higher iterations, just divide the
%                smallest value in the list by successive powers of two.
%                This list was produced by an aolder version of MKLSGRIDREFTRI.
%
% MaxEdgeOcta:   (numeric array) [deg]
%                List of maximum edge lengths of octahedron-based grids
%                (see MaxEdgeTetra for details)
%
% MaxEdgeIcosa:  (numeric array) [deg] 
%                List of maximum edge lengths of icosahedron-based grids
%                (see MaxEdgeTetra for details)
%
% MaxCCRTetra:  (numeric array) [deg]
%               List of maximum circumcircle radii for tetrahedron based
%               grids. The first element is the circumcircle radius of the
%               intial tetrahedron, the second element is the largest
%               circumcircle radius after one iteration, the third the same
%               after two iterations and so on.
%               The list given here gives radii only for a few iterations.
%               For higher iterations, just divide the smallest value in
%               the list by successive powers of two. This list was
%               produced by MKLSGRIDREFTRI.
%
% MaxCCROcta:   (numeric array) [deg]
%               List of maximum circumcircle radii for octahedron based
%               grids. See MaxCCRTetra for details.
%
% MaxCCRIcosa:  (numeric array) [deg]
%               LIst of maximum circumcircle radii for icosahedron based
%               grids. See MaxCCRTetra for details.
%
% LSPath:        (string)
%                path to the directory in which the LOCSMITH m-files reside
%                This is determinded dynamically as the path in which
%                MKLSCONSTANT resides.
%                No trailing slash/backslash.
%
% LSDocPathEN:   (string)
%                path to the directory in which the english LOCSMITH documentation
%                resides. This is the path to the HTML files of the english
%                version of the documentation, not to the images or
%                something else. Cosntructed via a recursive call to
%                MKLSCONSTANT('LSPath').
%                No trailing slash/backslash.
%
% HTMLHead:      (string)
%                HTML header for automatic generation of HTML files from
%                the help lines in m-files, used by MKHELP2HTML
%
% HTMLTitleOpen: (string)
%                Opening phrase for HTML page headline.
%                This is not the title-tag of the HTML page, but the headline
%                of the text.
%
% HTMLTitleClose: (string)
%                Closing phrase for HTML headline
%
% HTMLHelpBodyOpen:  (string)
%                This phrase opens the body part with the actual help lines
%
% HTMLHelpBodyClose: (string)
%                This phrase closes the body part with the actual help
%                lines.
%
% HTMLLinkOpen:  (string)
%                Opening Phrase for link to m-file source code.
%                The link URL has to bewritten between the opening and the
%                middle phrase.
%
% HTMLLinkMiddle (string)
%                Middle phrase for link to m-file source code. This is
%                mainly the constant part of the link text and the closing
%                '>' character fo the anchor opening tag.
%
% HTMLLinkClose: (string)
%                Closing phrase for link to m-file source code
%
% HTMLFoot:      (string)
%                HTML footer for automatic generation of HTML files from
%                the help lines in m-files, used by MKHELP2HTML
%
% HTMLTocLinkOpen: (string)
%                Opening phrase for TOC entries generated by MKHELP2HTML
%
% HTMLTocLinkMiddle: (string)
%                Middle phrase for TOC entries generated by MKHELP2HTML
%
% HTMLTocLinkClose: (string)
%                Closing phrase for TOC entries generated by MKHELP2HTML
%
%
%
% Martin Knapmeyer, 09.09.2004



constname=lower(constname);
switch constname
   
    %%%%%%%%%%%%%%%%%%%%%% YOU MAY CHANGE THE FOLLOWING CONSTANTS
    
    case {'referenceday'}
        constant=[1950 1 1];
        
    case {'transparency'}
        constant=0.25;
        
    case {'spherefacets'}
        constant=20;
        
    case {'colormaplength'}
        constant=256;
        
    case {'facecolor'}
        constant=[1 1 1]*0.8;
        
    case {'edgecolor'}
        constant='k';
        
    case {'nodecolor'}
        constant='r';
        
    case {'nodemarker'}
        constant='o';
        
    case {'stationmarker'}
        constant='^';
        
    case {'lighting'}
        constant='gouraud';
        

        
    %%%%%%%%%%%%%%%%%%%%%% YOU BETTER NOT CHANGE THE FOLLOWING CONSTANTS
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    
    case {'reftriroundoff'}
        constant=1e9;
        
    case {'trianglestetrahedron'}
        constant=4;
        
    case {'trianglesoctahedron'}
        constant=8;
        
    case {'trianglesicosahedron'}
        constant=20;
    
    case {'maxedgetetra'}
        constant=100*[...
                       1.09471220634491;...
                       0.90000000000000;...
                       0.60000000000000;...
                       0.33557309761921;...
                       0.17341442802760;...
                       0.08746013283241;...
                       0.04382586092509;...
                       0.02192495;...
                       0.01096398;...
                     ];
                 
    case {'maxedgeocta'}
        constant=[...
                   90.00000000000001;...
                   60.00000000000001;...
                   33.55730976192072;...
                   17.34144280275980;...
                    8.74601328324145;...
                    4.38258609250945;...
                    2.192495;...
                    1.096398;...
                 ];
             
    case {'maxedgeicosa'}
        constant=[...
                    63.43494882292203;...
                    36.00000000000003;...
                    18.69940708514921;...
                     9.44427551567520;...
                     4.73420528157983;...
                     2.36861896696099;...
                     1.18449927226541;...
                  ];
              
    case {'maxccrtetra'}
        constant=[...
                  70.528779365;...
                  54.735610317;...
                  35.264389682;...
                  19.471220634;...
                  10.024987862;...
                   5.051152528;...
                   2.530493039;...
                   1.265863813;...
                 ];
        
    case {'maxccrocta'}
        constant=[...
                  54.735610317;...
                  35.264389682;...
                  19.471220634;...
                  10.024987862;...
                   5.051152528;...
                   2.530493039;...
                   1.265863813;...
                 ];
        
    case {'maxccricosa'}
        constant=[...
                  37.377368140;...
                  20.905157447;...
                  10.812316963;...
                   5.454720361;...
                   2.733554118;...
                   1.367555265;...
                   0.683875033;...
                 ];
             
    case {'lspath'}
         %%% path to this m-file
         s=which('mklocsmith');
         %%% remove the file name from this string
         constant=strrep(s,[filesep 'mklocsmith.m'],'');
        
    case {'lsdocpathen'}
         constant=[mklsconstants('LSPath') filesep 'doc' filesep 'en'];
         
         
    case {'locationdemo1'}
        constant.slon=[-23.4200 -17.4800 3.6600 15.5100];
        constant.slat=[-3.0400 -3.6500 26.0800 -8.9700];
        constant.selv=[0 0 0 0];
        constant.hlon=60;
        constant.hlat=0;
        constant.hdep=0;
        constant.dbaz=[1 1 1 1]*2;
        constant.bazbias=[0 0 0 0];
        constant.ot=mkymdhms2rjd([2000 1 1 14 15 16],mklsconstants('ReferenceDay'));
        constant.phase='P';
        constant.dt=[];
        constant.tbias=[];
        pradius=6371;
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius,...
              'grid_init_maxr',pradius,...
              'grid_init_dr',pradius,... % only one layer for testing!
              'grid_init_wdt',8000,...
              'iter_circmin',200,...
              'iter_max',200,...
              'iter_drmin',10000,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1);
        
    case {'locationdemo2'}
        constant.slon=[-90 10.0250 118.3471 -131.0969];
        constant.slat=[60 -16.7787 6.8675 -44.1807];
        constant.selv=[0 0 0 0];
        constant.hlon=constant.slon(1)+0.1;
        constant.hlat=constant.slat(1);
        constant.hdep=0;
        constant.dbaz=[1 1 1 1]*2;
        constant.bazbias=[0 0 0 0];
        constant.ot=mkymdhms2rjd([2000 1 1 14 15 16],mklsconstants('ReferenceDay'));
        constant.phase='P';
        constant.dt=[];
        constant.tbias=[];
        pradius=6371;
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius,...
              'grid_init_maxr',pradius,...
              'grid_init_dr',pradius,... % only one layer for testing!
              'grid_init_wdt',8000,...
              'iter_circmin',100,...
              'iter_max',200,...
              'iter_drmin',10000,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1);
        
    case {'locationdemo3'}
        constant.slon=[-23.4200 -17.4800 3.6600 15.5100];
        constant.slat=[-3.0400 -3.6500 26.0800 -8.9700];
        constant.selv=[0 0 0 0];
        constant.hlon=30; %72; %60;
        constant.hlat=30; %90-2*asin(sqrt(2/(5+sqrt(5))))/(pi/180); %30; %0;
        constant.hdep=0; % 100;
        constant.dbaz=[];
        constant.bazbias=[];
        constant.ot=mkymdhms2rjd([1950 1 1 2 3 4],mklsconstants('ReferenceDay'));
        constant.phase=strvcat('P'); %,'S'); %,'S','PP');
        constant.dt=[1 1 1 1]*2; % travel time uncertainty in sec
        constant.tbias=[0 0 0 0]; % travel time bias in sec
        pradius=6371;
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius,...
              'grid_init_maxr',pradius,...
              'grid_init_dr',pradius,... % only one layer for testing!
              'grid_init_wdt',8000,...
              'iter_circmin',100,...
              'iter_max',200,...
              'iter_drmin',10000,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1);
        
    case {'locationdemo4'}
        constant.slon=[-80 -30 50 -60];
        constant.slat=[30 60 -30 -60];
        constant.selv=[0 0 0 0 0];
        constant.hlon=-31;
        constant.hlat=-33;
        constant.hdep=527; 
        constant.dbaz=[];
        constant.bazbias=[];
        constant.ot=mkymdhms2rjd([1950 1 1 2 3 4],mklsconstants('ReferenceDay'));
        constant.phase=strvcat('P','pP','S');
        constant.dt=[1 1 1 1 1]*4; % travel time uncertainty in sec
        constant.tbias=[0 0 0 0 0]; % travel time bias in sec
        pradius=6371;
        layerbottom=1000; % layer bottom depth
        layertop=100; % layer top depth
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius-constant.hdep,... 
              'grid_init_maxr',pradius-constant.hdep,... 
              'grid_init_dr',pradius-constant.hdep,... % only one layer!
              'grid_init_wdt',8000,...
              'iter_matchthresh',100,...
              'iter_circmin',50,...
              'iter_max',200,...
              'iter_drmin',10,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1);
          
              
     case {'locationdemo5'}
        constant.slon=[-80 -30 50 -60];
        constant.slat=[30 60 -30 -60];
        constant.selv=[0 0 0 0 0];
        constant.hlon=-31;
        constant.hlat=-33;
        constant.hdep=527; 
        constant.dbaz=[];
        constant.bazbias=[];
        constant.ot=mkymdhms2rjd([1950 1 1 2 3 4],mklsconstants('ReferenceDay'));
        constant.phase=strvcat('P','pP','S');
        constant.dt=[1 1 1 1 1]*4; % travel time uncertainty in sec
        constant.tbias=[0 0 0 0 0]; % travel time bias in sec
        pradius=6371;
        layerbottom=1000; % layer bottom depth
        layertop=100; % layer top depth
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius-layerbottom,...
              'grid_init_maxr',pradius-layertop,...
              'grid_init_dr',layerbottom-layertop,... % start with two depth samples!
              'grid_init_wdt',8000,...
              'iter_circmin',50,...
              'iter_max',200,...
              'iter_drmin',100,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1); 
          
              
     case {'locationdemo6'}
        constant.slon=[-80 -30 50]; %  -90 0];
        constant.slat=[30 60 -30 ]; % -80 -60];
        constant.selv=[0 0 0 0 0];
        constant.hlon=-31; %72; %60;
        constant.hlat=-33; %90-2*asin(sqrt(2/(5+sqrt(5))))/(pi/180); %30; %0;
        constant.hdep=527; 
        constant.dbaz=[];
        constant.bazbias=[];
        constant.ot=mkymdhms2rjd([1950 1 1 2 3 4],mklsconstants('ReferenceDay'));
        constant.phase=strvcat('P','pP','S'); %,'S'); %,'S','PP');
        constant.dt=[1 1 1 1 1]*2.5; % travel time uncertainty in sec
        constant.tbias=[0 0 0 0 0]; % travel time bias in sec
        pradius=6371;
        layerbottom=1000; % layer bottom depth
        layertop=100; % layer top depth
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius-constant.hdep,... 
              'grid_init_maxr',pradius-constant.hdep,... 
              'grid_init_dr',pradius-constant.hdep,... % only one layer!
              'grid_init_wdt',8000,...
              'iter_circmin',50,...
              'iter_max',200,...
              'iter_drmin',100,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1);
          
    case {'locationdemo7'}
        constant.slon=[-80 -30]; % 50 -60];
        constant.slat=[30 60]; % -30 -60];
        constant.selv=[0 0 0 0 0];
        constant.hlon=-31;
        constant.hlat=-33;
        constant.hdep=527; 
        constant.dbaz=[];
        constant.bazbias=[];
        constant.ot=mkymdhms2rjd([1950 1 1 2 3 4],mklsconstants('ReferenceDay'));
        constant.phase=strvcat('P'); %,'pP','S');
        constant.dt=[1 1 1 1 1]*4; % travel time uncertainty in sec
        constant.tbias=[0 0 0 0 0]; % travel time bias in sec
        pradius=6371;
        layerbottom=1000; % layer bottom depth
        layertop=100; % layer top depth
        constant.lsopt=mklsopt(...
              'planet_radius',pradius,...
              'grid_type','triangular',...
              'grid_base','icosahedron',...
              'grid_init_minr',pradius-constant.hdep,...
              'grid_init_maxr',pradius-constant.hdep,...
              'grid_init_dr',pradius-constant.hdep,... % start with two depth samples!
              'grid_init_wdt',8000,...
              'iter_circmin',50,...
              'iter_max',200,...
              'iter_drmin',10000,...
              'iter_searchmode','interior',...
              'eval_baz','on',...
              'eval_at','on',...
              'eval_dt','off',...
              'verbosity',1,...
              'verbosity_plot_mode','fitcloudmap',...
              'verbosity_plot_fig',1); 
              
        
    case {'htmlhead'}
        constant='<html><head><LINK REL=STYLESHEET TYPE="text/css" HREF="../../css/content.css"></head><body>';
        
    case {'htmltitleopen'}
        constant='<h4>Program: ';
        
    case {'htmltitleclose'}
        constant='</h4>';
        
    case {'htmlhelpbodyopen'}
        constant='<pre>';
        
    case {'htmlhelpbodyclose'}
        constant='</pre>';
        
    case {'htmllinkopen'}
        constant='<p><a href="';
        
    case {'htmllinkmiddle'}
        constant='" target="extern">Read M-File Source Code';
        
    case {'htmllinkclose'}
        constant='</a></p>';
        
    case {'htmlfoot'}
        constant='<hr>eof.</body></head>';
        
    case {'htmltoclinkopen'}
        constant='<h4><a href="../mfiles/';
        
    case {'htmltoclinkmiddle'}
        constant='.html" target="content">';
        
    case {'htmltoclinkclose'}
        constant='</a></h4>';
        
        
    otherwise
        error(['MKLSCONSTANTS: unknown constant ' upper(constname)]);
end; % switch constname
