function mklshelp2html(subdir);
% mklshelp2html.......convert matlab help lines into HTML files
%
% call: mklshelp2html(subdir);
%
%       subdir: (string)
%               This string defines the subdirectory of the LOCSMITH
%               base directory for which HTML files shall be generated.
%               This must be empty or an existing subdirectory!
%
%
% result: none
%
% This routine reads the help lines of all .m files and writes them into
% HTML files. HTML headers and footers as well as save paths are taken from
% MKLSCONSTANTS, so the conversion process can run fully automatically.
%
% The program writes one .html file per .m file and one file toc_list.html
% that contains a list of links to all these files which may be copied into
% the actual toc files of the online documentation. The latter is written
% into subdirectory "toc" of the directory that contains the .html files.
% This subdirectory must exist prior to executing MKLSHELP2HTML!
%
% The .html files for the individual m-files are written into subdirectory
% "mfiles" of the doc/en directory of the online documentation. This
% subdirectory must exist prior to execution of MKLSHELP2HTML!
%
% Martin Knapmeyer, 28.09.2004


%%% get HTML header
htmlhead=mklsconstants('HTMLHead');
htmltitleopen=mklsconstants('HTMLTitleOpen');
htmltitleclose=mklsconstants('HTMLTitleClose');
htmlhelpbodyopen=mklsconstants('HTMLHelpBodyOpen');
htmlhelpbodyclose=mklsconstants('HTMLHelpBodyClose');
htmllinkopen=mklsconstants('HTMLLinkOpen');
htmllinkmiddle=mklsconstants('HTMLLinkMiddle');
htmllinkclose=mklsconstants('HTMLLinkClose');
htmlfoot=mklsconstants('HTMLFoot');
htmltoclinkopen=mklsconstants('HTMLTocLinkOpen');
htmltoclinkmiddle=mklsconstants('HTMLTocLinkMiddle');
htmltoclinkclose=mklsconstants('HTMLTocLinkClose');


%%% get paths
readpath=[mklsconstants('LSPath') filesep subdir];
writepath=[mklsconstants('LSDocPathEN') filesep 'mfiles'];
tocpath=[mklsconstants('LSDocPathEN') filesep 'toc'];


%%% get file listing
filelist=dir([readpath filesep '*.m']);


%%% open toc file for saving link list
[tocfid,msg]=fopen([tocpath filesep 'toc_list_' subdir '.html'],'w');
if tocfid==-1
    error(['MKLSHELP2HTML: ' msg]);
end; % if tocfid

%%% loop over all files
fileanz=length(filelist);
for indy=1:fileanz
    
    %%% which file?
    currentfile=filelist(indy).name;
    [pathstr,savename]=fileparts([currentfile]);
    disp(['MKLSHELP2HTML: processing ' currentfile]);
    
    %%% get help lines
    helplines=help(currentfile);
    
    %%% construct complete content of HTML file
    htmltext=[htmlhead,...
                     htmltitleopen,...
                        upper(savename),...
                     htmltitleclose,...
                     htmlhelpbodyopen,...
                        helplines,...
                     htmlhelpbodyclose,...
                     htmllinkopen,...
                         [readpath filesep savename '.m'],...
                         htmllinkmiddle,...
                     htmllinkclose,...
                     htmlfoot...
                    ];
          
    %%% save HTML file
    [fid,msg]=fopen([writepath filesep savename '.html'],'w');
    if fid==-1
        error(['MKLSHELP2HTML: ' msg]);
    end; % if fid
    fprintf(fid,'%s',htmltext);
    fclose(fid);
    
    %%% write entry for toc_list file
    tocentry=[htmltoclinkopen,...
              savename,...
              htmltoclinkmiddle,...
              savename,...
              htmltoclinkclose];
    fprintf(tocfid,'%s\n',tocentry);
    
end; % for indy


%%% close toc file
fclose(tocfid);