function mklsverbose(verbosity,lsopt,varargin);
% mklsverbose.......produce text output in verbose modes
%
% call: mklsverbose(verbosity,lsopt,output1,output2,...);
%
%
%       verbosity: (number)
%                  verbosity level of current message.
%                  Message will be displayed to the screen only if
%                  eviopt.verbosity>verbosity
%       lsopt: (struct)
%               LOCSMITH options as returned by MKLSOPT
%               expected fields:
%               .verbosity: [numeric]
%                           defines verbosity level. The higher this
%                           number, the more messages will be written.
%                           verbosity=0 results in absolute silence.
%
%       output1, output2,... (string or numeric)
%             a list of strings and numercial values to be written
%             to the screen. STRUCTS and Cell arrays are not allowed!
%             MKVERBOSE uses the VARARGIN-mechanism to be able to
%             collect an arbitrary number of output variables.
%             These are concatenated into a string in the same sequence
%             they occur in the argument list.
%
%             Strings are concatenated as they are, the user has to take
%             care for separating spaces between numbers etc.
%
% result: none
%
% Examples:
% (appropriate settings for VERBOSITY and LSOPT assumed)
%
% mkeviverbose(v,lsopt,'Hello ',17,' World!',[23 42],'This is my Output!');
% produces
% Hello 17 World!23  42This is my Output!
%
% whereas
% mkeviverbose(0,lsopt,'Hello ',17,' World!',[23 42],'This is my Output!');
% produces nothing. (and does not waste CPU time!)
%
% Note that you do not need int2str and num2str, these conversions are
% applied internally.
%
%
% Martin Knapmeyer, 17.01.2003, 17.09.2004

if lsopt.verbosity<1
   return;
else
   if lsopt.verbosity>=verbosity
      %%% construct string from varargin-cell-array
      [nin1,nin2]=size(varargin); % nin2 is the number of input parameters
      outstring=char(zeros(1,verbosity-1)+46); %[]; % buold output string in here
      for indy=1:nin2
          piece=varargin{indy};
          if isstr(piece)
             outstring=[outstring piece];
          else
             outstring=[outstring num2str(piece)];
          end; % if isstr else
      end; % for indy
      %%% display string
      disp(outstring);
   end; % if lsopt.verbosity
end; % if verbosity