function [x,y]=mkhammer(lon,lat,mapopt,direction);
% mkhammer.......Hammer projection (equal area)
%
% call: [x,y]=mkhammer(lon,lat,mapopt,direction);
%
%       lon: arbitrary matrix of longitude values [deg]
%       lat: arbitrary matrix of latitude values [deg]
%       mapopt: map options structure as returned by MKMAPOPT
%       direction: projection direction:
%                  'forward': transform lon/lat to x/y
%                  'inverse': transform x/y to lon/lat
%
% result: x: matrix x coordinates
%         y: matrix of y coordinates
%
%         X and Y have same size and shape as LON and LAT (values with equal index correspond)
%         but are projected and scaled according to the settings in MAPOPT
%
% The Hammer projection is an equal area projection.
% It expects longitudes from -180 to 180, so better define mapopt.proj_range to be
% [-180 180 -90 90]!
% The Hammer projection is intended for whole-planet maps.
%
% Martin Knapmeyer, 02.07.2003


%%% a useful constant
radian=pi/180;

%%% if there are longitudes>180deg, subtract 180 from all longitudes
if ~isempty(find(lon>180))
   lon=lon-180;
end; % if ~isempty(find(lon>180))



switch lower(mapopt.planet_type)
    case {'sphere','uni'}
         switch direction
             case {'forward'}
                  %%% equations according to Schroeder, Kartennetzentwuerfe der Erde
                  w=90-lat;
                  w=w*radian;
                  lon=lon*radian;
                  denom=sqrt(1+cos(lon/2).*sin(w));
                  x=mapopt.planet_radius(1)*2*sqrt(2)*sin(lon/2).*sin(w)./denom;
                  y=mapopt.planet_radius(1)*sqrt(2)*cos(w)./denom;
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'bi'}
         error([': planet type ' upper(mapopt.planet_type) ' not yet available!']);
         switch direction
             case {'forward'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'tri'}
         error([': planet type ' upper(mapopt.planet_type) ' not yet available!']);
         switch direction
             case {'forward'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    otherwise
         error([': unknwon planet type ' upper(mapopt.planet_type)]);
end; %  switch mapopt.planet_type