function [x,y]=mklambert(lon,lat,mapopt,direction);
% mklambert.......Lambert's equal area azimutha projection
%
% call: [x,y]=mklambert(lon,lat,mapopt,direction);
%
%       lon: arbitrary matrix of longitude values [deg]
%       lat: arbitrary matrix of latitude values [deg]
%       mapopt: map options structure as returned by MKMAPOPT
%       direction: projection direction:
%                  'forward': transform lon/lat to x/y
%                  'inverse': transform x/y to lon/lat
%
% result: x: matrix x coordinates
%         y: matrix of y coordinates
%
%         X and Y have same size and shape as LON and LAT (values with equal index correspond)
%         but are projected and scaled according to the settings in MAPOPT
%
%
%
%
% Martin Knapmeyer, 07.07.2003


% a useful constant
radian=pi/180;


switch lower(mapopt.planet_type)
    case {'sphere','uni'}
         switch direction
             case {'forward'}
                  %%% equations according to Schroeder, Kartennetzentwuerfe der Erde
                  %%% some beautification in advance:
                  %%% rotate data such that middle meridian is vertical
                  midlon=mean([min(lon(:)) max(lon(:))]);
                  lon=lon-midlon-90;
                  %%% application of the mapping equations
                  lon=lon*radian;
                  colat=(90-lat)*radian;
                  sinu=mapopt.planet_radius(1)*sin(colat/2);
                  x=sinu.*cos(lon);
                  y=sinu.*sin(lon);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'bi'}
         error([': planet type ' upper(mapopt.planet_type) ' not yet available!']);
         switch direction
             case {'forward'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'tri'}
         error([': planet type ' upper(mapopt.planet_type) ' not yet available!']);
         switch direction
             case {'forward'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    otherwise
         error([': unknwon planet type ' upper(mapopt.planet_type)]);
end; %  switch mapopt.planet_type