function [x,y]=mklonlat2xy(lon,lat,mapopt,direction);
% mklonlat2xy.......transform lon/lat coordinates to x/y coordinates acc. to MAPOPT
%
% call: [x,y]=mklonlat2xy(lon,lat,mapopt,direction);
%
%       lon: arbitrary matrix of longitude values [deg]
%       lat: arbitrary matrix of latitude values [deg]
%       mapopt: map options structure as returned by MKMAPOPT
%       direction: projection direction:
%                  'forward': transform lon/lat to x/y
%                  'inverse': transform x/y to lon/lat
%
%
% result: x: matrix x coordinates
%         y matrix of y coordinates
%
%         X and Y have same size and shape as LON and LAT (values with equal index correspond)
%         but are projected and scaled according to the settings in MAPOPT
%
% MKLONLAT2XY dispatches the data to the respective projection routines.
% Nothing is plotted here.
%
% Martin Knapmeyer, 01.07.2003, 13.09.2006, 26.11.2007


%%% apply rotation to data
if ~isempty(mapopt.proj_pole)
   if ~isempty(mapopt.proj_pole) % MK26112007
      [lon,lat]=mkmaprotate(lon,lat,mapopt);
   end; % if ~isempty(mapopt.proj_pole)
end; % if ~isempty(mapopt.proj_pole)


switch lower(mapopt.proj_type)
   case {'plain'}
        x=lon;
        y=lat;
   case {'platecaree','platecarree'}
        [x,y]=mkplatecaree(lon,lat,mapopt,direction);
   case {'hammer'}
        [x,y]=mkhammer(lon,lat,mapopt,direction);
   case {'stereographic'}
        [x,y]=mkstereographic(lon,lat,mapopt,direction);
   case {'lambert'}
        [x,y]=mklambert(lon,lat,mapopt,direction);
   case {'orthographic'}
        [x,y]=mkorthographic(lon,lat,mapopt,direction);
   case {'globusmodelkit'}
        [x,y]=mkglobusmodelkit(lon,lat,mapopt,direction);
   otherwise
        error(['MKLONLAT2XY: unknown projection type ' upper(mapopt.proj_type)]);
end; % switch mapopt.proj_type