function [framelon,framelat,frameelv]=mkmakeframe(mapopt,minz,maxz);
% mkmakeframe.........generate map frame data
%
% call: [framelon,framelat]=mkmakeframe(mapopt,minz,maxz);
%
%       mapopt: map option structure as created by MKMAPOPT
%       minz: minimum elevation [m]
%       maxz: maximum elevation [m]
%
%       NOTE that mapopt.proj_range is used to determine the frame size
%
% result: framelon: matrix containing frame longitude data [deg]
%         framelat: matrix containing frame latitude data [deg]
%         frameelv: matrix containing frame z data [m]
%
%         FRAMELON, FRAMELAT and FRAMEELV are vectors of coordinates.
%         Each contains several line segments separated by NaNs.
%
% The constructed frame will be a wireframe of a 3D box.
%
% Martin Knapmeyer 07.07.2003

%%% init result
framelon=[];
framelat=[];
frameelv=[];

%%% mesh widths
meshwdt=mapopt.grid_lonmesh;
meshhgt=mapopt.grid_latmesh;

%%% longitude/latitude ranges
minlon=mapopt.proj_range(1);
maxlon=mapopt.proj_range(2);
minlat=mapopt.proj_range(3);
maxlat=mapopt.proj_range(4);

%%% southern boundary

lon=minlon:(abs(maxlon-minlon)/mapopt.grid_points):maxlon;
lat=lon*0+minlat;
minelv=lon*0+minz;
maxelv=lon*0+maxz;
framelon=[framelon, NaN, lon, NaN, lon];
framelat=[framelat, NaN, lat, NaN, lat];
frameelv=[frameelv, NaN, minelv, NaN, maxelv];


%%% northern boundary

lon=minlon:(abs(maxlon-minlon)/mapopt.grid_points):maxlon;
lat=lon*0+maxlat;
minelv=lon*0+minz;
maxelv=lon*0+maxz;
framelon=[framelon, NaN, lon, NaN, lon];
framelat=[framelat, NaN, lat, NaN, lat];
frameelv=[frameelv, NaN, minelv, NaN, maxelv];


%%% western boundary
lat=minlat:(abs(maxlat-minlat)/mapopt.grid_points):maxlat;
lon=lat*0+minlon;
minelv=lon*0+minz;
maxelv=lon*0+maxz;
framelon=[framelon, NaN, lon, NaN, lon];
framelat=[framelat, NaN, lat, NaN, lat];
frameelv=[frameelv, NaN, minelv, NaN, maxelv];

%%% eastern boundary
lat=minlat:(abs(maxlat-minlat)/mapopt.grid_points):maxlat;
lon=lat*0+maxlon;
minelv=lon*0+minz;
maxelv=lon*0+maxz;
framelon=[framelon, NaN, lon, NaN, lon];
framelat=[framelat, NaN, lat, NaN, lat];
frameelv=[frameelv, NaN, minelv, NaN, maxelv];

%%% NW vertical Edge
elv=minz:(abs(maxz-minz)/mapopt.grid_points):maxz;
lat=elv*0+maxlat;
lon=elv*0+minlon;
framelon=[framelon, NaN, lon];
framelat=[framelat, NaN, lat];
frameelv=[frameelv, NaN, elv];

%%% NE vertical Edge
elv=minz:(abs(maxz-minz)/mapopt.grid_points):maxz;
lat=elv*0+maxlat;
lon=elv*0+maxlon;
framelon=[framelon, NaN, lon];
framelat=[framelat, NaN, lat];
frameelv=[frameelv, NaN, elv];

%%% SE vertical Edge
elv=minz:(abs(maxz-minz)/mapopt.grid_points):maxz;
lat=elv*0+minlat;
lon=elv*0+maxlon;
framelon=[framelon, NaN, lon];
framelat=[framelat, NaN, lat];
frameelv=[frameelv, NaN, elv];

%%% SW vertical Edge
elv=minz:(abs(maxz-minz)/mapopt.grid_points):maxz;
lat=elv*0+minlat;
lon=elv*0+minlon;
framelon=[framelon, NaN, lon];
framelat=[framelat, NaN, lat];
frameelv=[frameelv, NaN, elv];



