function [grlon,grlat]=mkmakegrid(mapopt);
% mkmakegrid.......generate grid line data
%
% call: [grlon,grlat]=mkmakegrid(mapopt);
%
%       mapopt: Map Option structure as returned by MKMAPOPT
%
% result: grlon: matrix containing grid x coordinates
%         grlat: matrix containing grid y coordinates
%
%         GRLON and GRLAT are vectors of corrdinates.
%         Each contains coordinates for a number of lines
%         which are separated by NaNs, which allows to
%         plot the complete grid with a single plot command,
%         producing a single line object.
%
% Martin Knapmeyer, 02.07.2003


%%% init result
grlon=[];
grlat=[];

%%% mesh widths
meshwdt=mapopt.grid_lonmesh;
meshhgt=mapopt.grid_latmesh;

%%% longitude/latitude ranges
minlon=mapopt.grid_range(1);
maxlon=mapopt.grid_range(2);
minlat=mapopt.grid_range(3);
maxlat=mapopt.grid_range(4);

%%% largest and smallest lat/lon values used in grid
smallestlon=meshwdt*ceil(minlon/meshwdt);
largestlon=maxlon-mod(maxlon,meshwdt);
smallestlat=meshhgt*ceil(minlat/meshhgt); 
largestlat=maxlat-mod(maxlat,meshhgt);

% disp(['minlon=' int2str(minlon) ' => ' int2str(smallestlon)]);
% disp(['maxlon=' int2str(maxlon) ' => ' int2str(largestlon)]);
% disp(['minlat=' int2str(minlat) ' => ' int2str(smallestlat)]);
% disp(['maxlat=' int2str(maxlat) ' => ' int2str(largestlat)]);


%%% number of meridians to generate
merianz=fix(abs(largestlat-smallestlat)/meshhgt)+1;

%%% number of parallels to generate
parallanz=fix(abs(largestlon-smallestlon)/meshwdt)+1;


%%% generate meridians
for lineindy=0:(merianz-1)
   lons=minlon:(abs(maxlon-minlon)/mapopt.grid_points):maxlon;
   lats=lons*0+lineindy*meshhgt+smallestlat;
   grlon=[grlon, NaN, lons];
   grlat=[grlat, NaN, lats];
end; % for  lineindy

%%% generate parallels
for lineindy=0:(parallanz-1)
   lats=minlat:(abs(maxlat-minlat)/mapopt.grid_points):maxlat;
   lons=lons*0+lineindy*meshwdt+smallestlon;
   grlon=[grlon, NaN, lons];
   grlat=[grlat, NaN, lats];
end; % for lineindy

% %%% control plot
% plot([minlon maxlon maxlon minlon minlon],[minlat minlat maxlat maxlat minlat],'k-');
% hold on
% plot(grlon',grlat','r-');
% hold off
% axis([-180 180 -90 90]);
% grid on

