function [newlon,newlat]=mkmaprotate(lon,lat,mapopt);
% mkmaprotate.......rotate lon, lat data into new coordinate frame
%
% call: [newlon,newlat]=mkmaprotate(lon,lat,mapopt);
%
%       lon: longitudes of points to rotate [deg east]
%       lat: latitude of points to rotate [deg north]
%       mapopt: map options structure as returned by MKMAPOPT
%
% result: newlon: longitudes of rotated points [deg east]
%         newlat: latitudes of rotated points [deg north]
%
% applies the rotation defined by mapopt.proj_pole
%
% Martin Knapmeyer 30.10.2003, 11.05.2004

%%%% a dummy, until I have something better...
%newlon=lon;
%newlat=lat;


%%% a useful constant
radian=pi/180;



%%% spherical to cartesian
[x,y,z]=sph2cart(lon*radian,lat*radian,1);


% %%% rotate by LON degrees westward (around z axis)
angle=mapopt.proj_pole(1)*radian;
x2=x.*cos(angle)-y.*sin(angle);
y2=y.*cos(angle)+x.*sin(angle);
z2=z;
% x2=x; y2=y; z2=z;


% %%% rotate by 90-LAT degrees northward (around x axis)
angle=(180-(mapopt.proj_pole(2)+90))*radian;
x3=x2;
y3=y2.*cos(angle)-z2.*sin(angle);
z3=y2.*sin(angle)+z2.*cos(angle);
% x3=x2; y3=y2; z3=z2;

%%% cartesian to spherical
[newlon,newlat]=cart2sph(x3,y3,z3);
newlat=newlat/radian;
newlon=newlon/radian;

%%% newlon now ranges from -180 to 180
newlon=newlon+180;