function [x,y]=mkplatecaree(lon,lat,mapopt,direction);
% mkplotecaree.......plate caree projection
%
% call: [x,y]=mkplatecaree(lon,lat,mapopt,direction);
%
%       lon: arbitrary matrix of longitude values [deg]
%       lat: arbitrary matrix of latitude values [deg]
%       mapopt: map options structure as returned by MKMAPOPT
%       direction: projection direction:
%                  'forward': transform lon/lat to x/y
%                  'inverse': transform x/y to lon/lat
%
% result: x: matrix x coordinates
%         y matrix of y coordinates
%
%         X and Y have same size and shape as LON and LAT (values with equal index correspond)
%         but are projected and scaled according to the settings in MAPOPT
%
% The Plate Caree Projection is the most simple map projection:
% numerical values of longitude and latitude are interpreted as
% x and y coordinates without further computation.
%
% This projection conserves the lengths of the equator and of the meridians.
% Angles and areas are not conserved.
%
% Scaling is done by evaluation of arc length.
%
%
% Martin Knapmeyer, 01.07.2003


switch lower(mapopt.planet_type)
    case {'sphere','uni'}
         arclen=2*pi*mapopt.planet_radius(1)/360; % arc length in km per degree
         switch direction
             case {'forward'}
                  x=lon*arclen*mapopt.proj_scale;
                  y=lat*arclen*mapopt.proj_scale;
             case {'inverse'}
                  x=lon/(arclen*mapopt.proj_scale);
                  y=lat/(arclen*mapopt.proj_scale);
             otherwise
                  error(['MKPLATECAREE: unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'bi'}
         error(['MKPLATECAREE: planet type ' upper(mapopt.planet_type) ' not yet available!']);
    case {'tri'}
         error(['MKPLATECAREE: planet type ' upper(mapopt.planet_type) ' not yet available!']);
    otherwise
         error(['MKPLATECAREE: unknwon planet type ' upper(mapopt.planet_type)]);
end; %  switch mapopt.planet_type