function [x,y]=mkstereographic(lon,lat,mapopt,direction);
% mkstereographic........stereographic (azimuthal conformal)
%
% call: [x,y]=mkstereographic(lon,lat,mapopt,direction);
%
%       lon: arbitrary matrix of longitude values [deg]
%       lat: arbitrary matrix of latitude values [deg]
%       mapopt: map options structure as returned by MKMAPOPT
%       direction: projection direction:
%                  'forward': transform lon/lat to x/y
%                  'inverse': transform x/y to lon/lat
%
% result: x: matrix x coordinates
%         y: matrix of y coordinates
%
%         X and Y have same size and shape as LON and LAT (values with equal index correspond)
%         but are projected and scaled according to the settings in MAPOPT
%
% The stereographich projection is a conformal azimuthal projection.
% Circles on the globe are mapped to circles in the map.
%
%
% Martin Knapmeyer, 02.07.2003


% a useful constant
radian=pi/180;


switch lower(mapopt.planet_type)
    case {'sphere','uni'}
         switch direction
             case {'forward'}
                  %%% equations according to Schroeder, Kartennetzentwuerfe der Erde
                  %%% some beautification in advance:
                  %%% rotate data such that middle meridian is vertical
                  %midlon=mean([min(lon(:)) max(lon(:))]);
                  %lon=lon-midlon-90; NO! DANGEROUS NONSENSE!
                  %%% application of the mapping equations
                  lon=lon*radian;
                  lat=lat*radian;
                  denom=1+sin(lat);
                  x=mapopt.planet_radius(1)*cos(lon).*cos(lat)./denom;
                  y=mapopt.planet_radius(1)*sin(lon).*cos(lat)./denom;
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'bi'}
         error([': planet type ' upper(mapopt.planet_type) ' not yet available!']);
         switch direction
             case {'forward'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    case {'tri'}
         error([': planet type ' upper(mapopt.planet_type) ' not yet available!']);
         switch direction
             case {'forward'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             case {'inverse'}
                  error([': projection direction ' upper(direction)...
                         ' not yet available for planet type ' upper(mapopt.planet_type)]);
             otherwise
                  error([': unknown projection direction ' upper(direction)]);
         end; % switch direction
    otherwise
         error([': unknwon planet type ' upper(mapopt.planet_type)]);
end; %  switch mapopt.planet_type