function traveltimes=mklsemptytraveltimes(layeranz);
% mklsemptytraveltimes.........create empty travel times structure
%
% call: traveltimes=mklsemptytraveltimes;
%
% result: traveltimes: (structure array)
%                      universal travel time structure, denoting travel
%                      times from specified points to specified stations
%                      for specified phases.
%                      The structure contains the following fields:
%
%                      .layerid: (number) []
%                                ID of the layer from which the nodes in
%                                NODEID are
%                      .nodeid: (numeric array) []
%                               List of IDs of the nodes for which the 
%                               travel times were computed
%                      .phase: (string array)
%                              list of strings denoting the phases for which
%                              the travel times were computed
%                      .station (string array)
%                              list of strings denoting the stations for
%                              which the travel times were computed
%                      .d:     (numeric array) [deg]
%                              list of the epicentral distances of the
%                              nodes
%                      .tt:    (numeric array) [s]
%                              list of the travel times themselves
%
%                      traveltimes.nodeid(n) is the ID of the n-th node for
%                      which travel times were computed. The corresponding
%                      phase name is traveltimes.phase(n,:) and the travel
%                      time itself is traveltimes.tt(n), in seconds.
%
%                      By organizing the structure this way, it is easy to
%                      search for a certain node ID, phase name or travel
%                      times within a certain range.
%
%                      
%
% Martin Knapmeyer, 12.04.2005, 17.05.2005


traveltimes=repmat(struct('layerid',[],...
                          'nodeid',[],...
                          'phase','',...
                          'station','',...
                          'd',[],...
                          'tt',[]),...
                    layeranz,1);